@@ -29,21 +29,21 @@
  * @brief  enum for icons and images
  */
 typedef enum IconImg {
-    W_ICON_ADD,
-    W_ICON_ADD_DIR,
-    W_ICON_REMOVE,
-    W_ICON_SORT,
-    W_ICON_UP,
-    W_ICON_DOWN,
-    W_ICON_FLOPPY,
-    W_ICON_SCREEN,
-    W_ICON_DUPL,
-    W_ICON_INFO,
-    W_ICON_EXIT,
-    W_ICON_ABOUT,
-    W_IMG_SCREEN_1,
-    W_IMG_SCREEN_2,
-    W_IMG_SCREEN_3
+    W_ICON_ADD,      /**< Add images icon */
+    W_ICON_ADD_DIR,  /**< Add images from directory icon*/
+    W_ICON_REMOVE,   /**< Remove images from list icon */
+    W_ICON_SORT,     /**< Sort wallpapers on list icon */
+    W_ICON_UP,       /**< Move up icon */
+    W_ICON_DOWN,     /**< Move down icon */
+    W_ICON_FLOPPY,   /**< Save settings floppy icon */
+    W_ICON_SCREEN,   /**< Set wallpaper screen icon */
+    W_ICON_DUPL,     /**< Remove duplicates icon */
+    W_ICON_INFO,     /**< Info about application icon */
+    W_ICON_EXIT,     /**< Exit app icon */
+    W_ICON_ABOUT,    /**< About app dialog image */
+    W_IMG_SCREEN_1,  /**< Preview image top part (screen) */
+    W_IMG_SCREEN_2,  /**< Preview image middle part (screen) */
+    W_IMG_SCREEN_3   /**< Preview image bottom part (screen) */
 } IconImg;
 /*----------------------------------------------------------------------------*/
 /**
