@@ -24,7 +24,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include "miscfun.h"
+#include "cres.h"
 #include "iminfo.h"
 #include "strfun.h"
 /*----------------------------------------------------------------------------*/
@@ -54,7 +54,7 @@ static int
 compare_imageitems (const ImageInfo *ii_info1,
                     const ImageInfo *ii_info2)
 {
-    return compare_strings (ii_info1->s_file_name, ii_info2->s_file_name);
+    return str_compare (ii_info1->s_file_name, ii_info2->s_file_name);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -118,7 +118,7 @@ imageinfo_new_from_file (const char *s_fname)
         s_p++;
         imageinfo_set_file_name (ii_info, s_p);
 
-        s_path = str_ndup (s_fname, s_p - s_fname);
+        s_path = str_ndup (s_fname, (size_t) (s_p - s_fname));
         imageinfo_set_file_path (ii_info, s_path);
 
         free (s_path);
@@ -167,6 +167,7 @@ GSList * imageinfo_remove_duplicates (GSList *gsl_iinfo)
     GSList *gsl_act = NULL;
 
     for (gsl_itr = gsl_iinfo; gsl_itr; gsl_itr = gsl_itr->next) {
+
         gsl_nxt = gsl_itr->next;
 
         while (gsl_nxt) {
@@ -209,54 +210,6 @@ file_paths_to_imageinfo (GSList *gsl_files1)
     return gsl_iinfo;
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get image info of files in list and store it in FList.
- */
-GSList *
-flist_to_imageinfo (const FList *fl_files)
-{
-    ImageInfo  *ii_info;
-    GSList     *gsl_iinfo = NULL; /* Result ImageInfo list */
-    const char *s_fn      = NULL; /* File name string */
-    uint32_t    ui_cnt    = 0;    /* Number of items in file list */
-    uint32_t    i         = 0;
-
-    ui_cnt = flist_get_len (fl_files);
-
-    for (i = 0; i < ui_cnt; ++i) {
-
-        s_fn = flist_get_data (fl_files, i);
-        ii_info = imageinfo_new_from_file (s_fn);
-
-        if (imageinfo_get_height (ii_info) > 0)
-            gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
-    }
-    return gsl_iinfo;
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Extract file paths list of ImageInfo list and append to FList.
- */
-int
-imageinfo_append_to_flist (GSList *gsl_iinfo1,
-                           FList  *fl_files)
-{
-    GSList    *gsl_iinfo = NULL; /* Pointer to ImageInfo list */
-    ImageInfo *ii_info;
-
-    gsl_iinfo = gsl_iinfo1;
-
-    while (gsl_iinfo != NULL) {
-
-        ii_info = gsl_iinfo->data;
-
-        flist_insert_data (fl_files, imageinfo_get_full_name (ii_info));
-
-        gsl_iinfo = gsl_iinfo->next;
-    }
-    return 0;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set the full file name string (path + file name)
  */
@@ -387,7 +340,7 @@ imageinfo_set_wxh (ImageInfo *ii_info,
 const char *
 imageinfo_get_wxh (const ImageInfo *ii_info)
 {
-    return (const char*) ii_info->s_width_height;       
+    return (const char*) ii_info->s_width_height;
 }
 /*----------------------------------------------------------------------------*/
 
