@@ -28,19 +28,38 @@
 #define IMINFO_H
 
 #include <glib.h>
-#include "flist.h"
 /*----------------------------------------------------------------------------*/
 /**
+ * @struct ImageInfo
+ *
  * @brief  ImageInfo data structure
+ *
+ * @var   ImageInfo::s_full_path
+ * @brief Full file name with path
+ *
+ * @var   ImageInfo::s_file_name
+ * @brief File name only
+ *
+ * @var   ImageInfo::s_file_path
+ * @brief File path only
+ *
+ * @var   ImageInfo::s_width_height
+ * @brief String with Width x Height
+ *
+ * @var   ImageInfo::i_width
+ * @brief Image width int
+ *
+ * @var   ImageInfo::i_height
+ * @brief Image height int
  */
 typedef struct
 ImageInfo {
-    char    *s_full_path;     /**< Full file name with path */
-    char    *s_file_name;     /**< File name only */
-    char    *s_file_path;     /**< File path */
-    char    *s_width_height;  /**< Width x Height in string */
-    int      i_width;         /**< Image width in uint */
-    int      i_height;        /**< Image height in uint */
+    char    *s_full_path;     /* Full file name with path */
+    char    *s_file_name;     /* File name only */
+    char    *s_file_path;     /* File path */
+    char    *s_width_height;  /* Width x Height in string */
+    int      i_width;         /* Image width in uint */
+    int      i_height;        /* Image height in uint */
 } ImageInfo;
 /*----------------------------------------------------------------------------*/
 /**
@@ -82,30 +101,12 @@ GSList * imageinfo_sort               (GSList  *gsl_iinfo);
 GSList * imageinfo_remove_duplicates  (GSList  *gsl_iinfo);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  int imageinfo_append_to_flist  (GSList  *gsl_iinfo1,
- *                                      FList   *fl_files)
- * @brief      Extract file paths list of ImageInfo list and append to FList.
- * @param[in]  gsl_iinfo1  List with ImageInfo items
- * @param[out] fl_files    FList to append data
- * @return     Append result
- *
- * @fn  GSList * file_paths_to_imageinfo (GSList *gsl_files1)
  * @brief      Get image info of files in list and store it in ImageInfo list.
  * @param[in]  gsl_files1  File list to process
  * @return     List of ImageInfo items
- *
- * @fn  GSList * flist_to_imageinfo (FList *fl_files)
- * @brief      Get image info of files in list and store it in FList.
- * @param[in]  fl_files  File list to process
- * @return     List of ImageInfo items
  */
 /*----------------------------------------------------------------------------*/
-int      imageinfo_append_to_flist (GSList      *gsl_iinfo1,
-                                    FList       *fl_files);
-
 GSList * file_paths_to_imageinfo   (GSList      *gsl_files1);
-
-GSList * flist_to_imageinfo        (const FList *fl_files);
 /*----------------------------------------------------------------------------*/
 /**
  * @fn  void imageinfo_set_full_name (ImageInfo *ii_info, const char *s_name)
