@@ -24,12 +24,20 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <string.h>
+#include "../config.h"
+
+#ifdef HAVE_JSON_C_JSON_H
 #include <json-c/json.h>
+#else
+#include <json.h>
+#endif
+
 #include "errs.h"
 #include "setting.h"
-#include "miscfun.h"
-#include "jsfun.h"
+#include "rwdt.h"
 #include "strfun.h"
+#include "hashfun.h"
+#include "jsfun.h"
 /*----------------------------------------------------------------------------*/
 /**
  * @fn  static void js_json_array_to_stlist (json_object *j_array,
@@ -68,9 +76,9 @@
  *
  */
 /*----------------------------------------------------------------------------*/
-static void          js_json_array_to_stlist (json_object  *j_array,
-                                              SettList     *st_list,
-                                              const char   *s_array_name);
+static void          js_json_array_to_stlist (json_object        *j_array,
+                                              SettList           *st_list,
+                                              const char         *s_array_name);
 
 static void          js_stlist_array_to_json (const SettList     *st_list,
                                               const Setting      *st_sett,
@@ -125,7 +133,7 @@ js_json_array_to_stlist (json_object *j_array,
 
         if (j_val != NULL) {
 
-            s_name = string_name_with_number (s_array_name, i);
+            s_name = str_name_with_number (s_array_name, i);
 
             st_set = js_json_obj_to_setting (j_val, s_name, st_list);
 
@@ -196,9 +204,6 @@ js_json_string_to_stlist (const char *s_buff)
     SettList    *st_list;
     Setting     *st_set;
 
-    if (s_buff == NULL)
-        return NULL;
-
     st_list = stlist_new_list ();
 
     j_obj = json_tokener_parse (s_buff);
@@ -211,6 +216,7 @@ js_json_string_to_stlist (const char *s_buff)
             stlist_insert_setting (st_list, st_set);
     }
     json_object_put (j_obj);
+
     return st_list;
 }
 /*----------------------------------------------------------------------------*/
@@ -224,11 +230,12 @@ js_stlist_array_to_json (const SettList *st_list,
 {
     Setting     *st_val;
     json_object *j_obj;
-    SettList    *st_array_list = stlist_get_settings_in_array_obj (st_list,
-                                                                   st_sett);
+    SettList    *st_array_list;
     uint32_t     ui_cnt = 0;
     uint32_t     i      = 0;
 
+    st_array_list = stlist_get_settings_in_array_obj_p (st_list, st_sett);
+
     ui_cnt = stlist_get_length (st_array_list);
 
     for (i = 0; i < ui_cnt; ++i) {
@@ -239,7 +246,7 @@ js_stlist_array_to_json (const SettList *st_list,
 
         json_object_array_add (j_array, j_obj);
     }
-    stlist_free (st_array_list);
+    stlist_free_p (st_array_list);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -292,10 +299,7 @@ js_stlist_add_to_json_obj (const SettList *st_list,
     uint32_t     ui_cnt   = 0;
     uint32_t     i        = 0;
 
-    if (j_obj == NULL || st_list == NULL)
-        return;
-
-    st_main  = stlist_get_settings_main (st_list);
+    st_main  = stlist_get_settings_main_p (st_list);
 
     ui_cnt = stlist_get_length (st_main);
 
@@ -307,7 +311,7 @@ js_stlist_add_to_json_obj (const SettList *st_list,
 
         json_object_object_add (j_obj, setting_get_name (st_sett), j_val);
     }
-    stlist_free (st_main);
+    stlist_free_p (st_main);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -320,16 +324,18 @@ js_settings_read (const char *s_fname,
     SettList *st_list;
     char     *s_buff = NULL; /* File data buffer */
 
-    *i_err = read_file_data (s_fname, &s_buff);
-    if (*i_err)
+    s_buff = read_file_data (s_fname, i_err);
+
+    if (*i_err != ERR_OK)
         return NULL;
 
-    if (s_buff == NULL)
-        return NULL;
-
-    st_list = js_json_string_to_stlist (s_buff);
-
-    free (s_buff);
+    if (s_buff == NULL) {
+        st_list = stlist_new_list ();
+    }
+    else {
+        st_list = js_json_string_to_stlist (s_buff);
+        free (s_buff);
+    }
 
     return st_list;
 }
@@ -338,21 +344,24 @@ js_settings_read (const char *s_fname,
  * @brief  Check if settings in SettList are an update to settings
  *         stored in settings file.
  */
-int
+char *
 js_settings_check_for_update (const SettList  *st_list,
                               const char      *s_fname,
-                              char           **s_out_buff)
+                              int             *i_err)
 {
     json_object *j_obj;
-    const char  *s_jbuff = NULL;   /* Json object as string */
-    char        *s_buff  = NULL;   /* File data buffer */
-    uint64_t     ui_hash = 0;      /* File read hash */
-    int          i_res   = ERR_OK; /* Function result */
+    const char  *s_jbuff     = NULL;   /* Json object as string */
+    char        *s_buff      = NULL;   /* File data buffer */
+    char        *s_res_buff  = NULL;   /* Result data buffer */
+    uint32_t     ui_hash     = 0;      /* File read hash */
 
-    i_res = read_file_data_hash (s_fname, &s_buff, &ui_hash);
-    if (i_res) {
+    *i_err = ERR_OK;
+
+    s_buff = read_file_data_hash (s_fname, i_err, &ui_hash);
+
+    if (*i_err != ERR_OK) {
         free (s_buff);
-        return i_res;
+        return NULL;
     }
 
     if (s_buff == NULL) {
@@ -371,14 +380,15 @@ js_settings_check_for_update (const SettList  *st_list,
     /* Compare saved file buffer hash and new one,
      * if they are different update output buffer */
     if (hash (s_jbuff) != ui_hash) {
-        *s_out_buff = str_dup (s_jbuff);
+        s_res_buff = str_dup (s_jbuff);
     }
     else {
-        *s_out_buff = NULL;
+        s_res_buff = NULL;
     }
 
     json_object_put (j_obj);
-    return i_res;
+
+    return s_res_buff;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -400,15 +410,15 @@ js_settings_check_update_file (const SettList *st_list,
                                const char     *s_fname)
 {
     char *s_buff = NULL;
-    int   i_res  = 0;
-    
-    i_res = js_settings_check_for_update (st_list, s_fname, &s_buff);
+    int   i_err  = ERR_OK;
+
+    s_buff = js_settings_check_for_update (st_list, s_fname, &i_err);
 
     if (s_buff != NULL) {
-        js_settings_update_file (s_buff, s_fname);
+        i_err = js_settings_update_file (s_buff, s_fname);
         free (s_buff);
     }
-    return i_res;
+    return i_err;
 }
 /*----------------------------------------------------------------------------*/
 
