@@ -31,6 +31,9 @@
 /**
  * @brief  Get settings data from file.
  *
+ * Reads settings from json file, returns SettList with settings or empty if
+ * file is empty. Returns null if read error. Sets error code in i_err.
+ *
  * @param[in]  s_fname  Config file name
  * @param[out] i_err    Pointer to integer for error output
  * @return     SettList list of settings
@@ -40,28 +43,34 @@ SettList * js_settings_read (const char *s_fname,
                              int        *i_err);
 /*----------------------------------------------------------------------------*/
 /**
+ * @fn  char * js_settings_check_for_update (const SettList *st_list,
+ *                                           const char     *s_fname,
+ *                                           int            *i_err)
  * @brief  Check if settings in SettList are an update to settings
  *         stored in settings file.
  *
  * Function converts SettList list of settings to Json object, reads Json
  * data from file s_fname, and checks if they differ in content.
- * If there is no difference s_out_buff is set to null pointer, if they are
- * different, the new config Json raw data is written to s_out_buff.
- * Function returns ERR_OK if there is no error or appropriate error code.
+ * If there is no difference s_res_buff is set to null pointer and returned.
+ * If they are different, the new config Json raw data is written to
+ * s_res_buff and returned.
+ * Function saves error code in i_err.
  *
  * @param[in]  st_list     List of settings
  * @param[in]  s_fname     Config file name
- * @param[out] s_out_buff  Buffer to write data
- * @return     ERR_OK or error code
+ * @param[out] i_err       Error output
+ * @return     String with updated settings or null if there is no update.
  *
- * @fn  int js_settings_update_file (const char *s_buff, const char *s_fname);
+ *
+ * @fn  int js_settings_update_file (const char *s_buff, const char *s_fname)
  * @brief      Update file with new data
  * @param[in]  s_buff   String with data to save
  * @param[in]  s_fname  File name to save data
  * @return     Saving file status, ERR_OK or error code
  *
+ *
  * @fn  int js_settings_check_update_file (const SettList *st_list,
- *                                         const char     *s_fname);
+ *                                         const char     *s_fname)
  * @brief  Check if settings are an update and update file with new data
  *         if they are.
  *
@@ -73,15 +82,15 @@ SettList * js_settings_read (const char *s_fname,
  * @return     Saving file status, ERR_OK or error code
  */
 /*----------------------------------------------------------------------------*/
-int js_settings_check_for_update  (const SettList  *st_list,
-                                   const char      *s_fname,
-                                   char           **s_out_buff);
+char * js_settings_check_for_update  (const SettList  *st_list,
+                                      const char      *s_fname,
+                                      int             *i_err);
 
-int js_settings_update_file       (const char      *s_buff,
-                                   const char      *s_fname);
+int    js_settings_update_file       (const char      *s_buff,
+                                      const char      *s_fname);
 
-int js_settings_check_update_file (const SettList  *st_list,
-                                   const char      *s_fname);
+int    js_settings_check_update_file (const SettList  *st_list,
+                                      const char      *s_fname);
 /*----------------------------------------------------------------------------*/
 #endif
 
