@@ -109,7 +109,6 @@ randomm_clear (RandMem *rm_mem)
 
     for (i = 0; i < RMMAX; ++i)
         rm_mem->ui_rand[i] = 0;
-    rm_mem->ui_cnt = 0;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -119,6 +118,7 @@ void
 randomm_init (RandMem *rm_mem)
 {
     randomm_clear (rm_mem);
+    rm_mem->ui_cnt = 0;
     rm_mem->ui_range = 0;
     srand (time (0));
 }
@@ -130,7 +130,6 @@ void
 randomm_set_range (RandMem *rm_mem,
                    uint32_t ui_rng)
 {
-    randomm_clear (rm_mem);
     rm_mem->ui_range = ui_rng;
 }
 /*----------------------------------------------------------------------------*/
@@ -156,7 +155,7 @@ randomm_get_number (RandMem *rm_mem)
 
     /* Get random number and check if it is in memory */
     do {
-        ui_ret = rand () % rm_mem->ui_range;
+        ui_ret = (uint32_t) rand () % rm_mem->ui_range;
     }
     while (randomm_check_number (rm_mem, ui_ret));
 
@@ -167,6 +166,7 @@ randomm_get_number (RandMem *rm_mem)
 
     if (rm_mem->ui_cnt >= rm_mem->ui_range) {
         randomm_clear (rm_mem);
+        randomm_reset_cnt (rm_mem);
     }
     return ui_ret;
 }
