@@ -30,18 +30,30 @@
 #ifndef RANDOMM_H
 #define RANDOMM_H
 
+#define RMMAX 1000  /**< RMMAX * 32 maximum random number range */
+
 #include <stdint.h>
 
-#define RMMAX 200  /**< RMMAX * 32 maximum random number range */
 /*----------------------------------------------------------------------------*/
 /**
+ * @struct RandMem
+ *
  * @brief  Random memory struct
+ *
+ * @var   RandMem::ui_rand
+ * @brief Table to store information which number was randomed
+ *
+ * @var   RandMem::ui_range
+ * @brief Max random number that will be generated
+ *
+ * @var   RandMem::ui_cnt
+ * @brief Number of random number generated in a serie
  */
 typedef struct
 RandMem {
-    uint32_t ui_rand[RMMAX]; /**< Memory table which numbers were randomed */
-    uint32_t ui_range;       /**< Max random number to generate */
-    uint32_t ui_cnt;         /**< How many times random was executed */
+    uint32_t ui_rand[RMMAX];
+    uint32_t ui_range;
+    uint32_t ui_cnt;
 } RandMem;
 /*----------------------------------------------------------------------------*/
 /**
@@ -67,7 +79,8 @@ void randomm_init (RandMem *rm_mem);
  * @param[in]  ui_rng  Range value
  * @return     none
  */
-void randomm_set_range (RandMem *rm_mem, uint32_t ui_rng);
+void randomm_set_range (RandMem  *rm_mem,
+                        uint32_t  ui_rng);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Reset random number couts value
