@@ -24,90 +24,94 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include "setting.h"
 #include "strfun.h"
+#include "hashfun.h"
+#include "setting.h"
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Hash function.
+ * @brief  Calls hash function
  */
-static uint64_t
-hash (const char *str)
+uint32_t
+setting_hashfun (const char *str)
 {
-    uint64_t hash = 5381;
-    int         c = 0;
-
-    if (str == NULL)
-        return 0;
-
-    while ((c = *str++)) {
-        hash = ((hash << 5) + hash) + c;
-    }
-    return hash;
-}
-/*----------------------------------------------------------------------------*/
-uint64_t
-setting_hashfun (const char *s_str)
-{
-    return hash (s_str);
+    return hash (str);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set the type of setting
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_type  Type of setting
+ * @return     none
+ */
 static void
 setting_set_type (Setting          *st_set,
                   const SetValType  i_type)
 {
-    if (st_set == NULL)
-        return;
-
     st_set->v_type = i_type;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get the type of setting
+ */
 SetValType
 setting_get_type (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     return st_set->v_type;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting id value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Id value
+ * @return     none
+ */
 static void
 setting_set_id (Setting        *st_set,
-                const uint64_t  i_val)
+                const uint32_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     st_set->i_id = i_val;
 }
 /*----------------------------------------------------------------------------*/
-uint64_t
+/**
+ * @brief      Get Setting id number
+ */
+uint32_t
 setting_get_id (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     return st_set->i_id;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting owner id value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Owner id value
+ * @return     none
+ */
 static void
 setting_set_owner_id (Setting        *st_set,
-                      const uint64_t  i_val)
+                      const uint32_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     st_set->i_owner_id = i_val;
 }
 /*----------------------------------------------------------------------------*/
-uint64_t
+/**
+ * @brief  Get Setting object's owner id number
+ */
+uint32_t
 setting_get_owner_id (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     return st_set->i_owner_id;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Setting initialization
+ *
+ * @param[out] st_set  Setting object
+ * @return     none
+ */
 static void
 setting_init (Setting *st_set)
 {
@@ -118,21 +122,24 @@ setting_init (Setting *st_set)
     st_set->data.i64_val = 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free string data in Setting
+ *
+ * @param[out] st_set  Setting object
+ * @return     none
+ */
 static void
 setting_free_string (Setting *st_set)
 {
-    if (st_set == NULL)
-        return;
-
     free (st_set->data.s_val);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free Setting object
+ */
 void
 setting_free (Setting *st_set)
 {
-    if (st_set == NULL)
-        return;
-
     free (st_set->s_name);
 
     if (setting_get_type (st_set) == SET_VAL_STRING) {
@@ -141,351 +148,410 @@ setting_free (Setting *st_set)
     free (st_set);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of int data
+ * @return     none
+ */
 static void
 setting_set_int (Setting       *st_set,
                  const int64_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_INT);
 
     st_set->data.i_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get integer value stored in Setting
+ */
 int64_t
 setting_get_int (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_INT)
         return st_set->data.i_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 64 bit int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 64 bit int data
+ * @return     none
+ */
 static void
 setting_set_int64 (Setting       *st_set,
                    const int64_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_INT64);
 
     st_set->data.i64_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 64 bit integer value stored in Setting
+ */
 int64_t
 setting_get_int64 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_INT64)
         return st_set->data.i64_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 32 bit int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 32 bit int data
+ * @return     none
+ */
 static void
 setting_set_int32 (Setting       *st_set,
                    const int32_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_INT32);
 
     st_set->data.i32_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 32 bit integer value stored in Setting
+ */
 int32_t
 setting_get_int32 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_INT32)
         return st_set->data.i32_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 16 bit int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 16 bit int data
+ * @return     none
+ */
 static void
 setting_set_int16 (Setting       *st_set,
                    const int16_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_INT16);
 
     st_set->data.i16_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 16 bit integer value stored in Setting
+ */
 int16_t
 setting_get_int16 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_INT16)
         return st_set->data.i16_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 8 bit int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 8 bit int data
+ * @return     none
+ */
 static void
 setting_set_int8 (Setting      *st_set,
                   const int8_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_INT8);
 
     st_set->data.i8_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 8 bit integer value stored in Setting
+ */
 int8_t
 setting_get_int8 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_INT8)
         return st_set->data.i8_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting unsigned int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of unsigned int data
+ * @return     none
+ */
 static void
 setting_set_uint (Setting        *st_set,
                   const uint64_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_UINT);
 
     st_set->data.ui_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get unsigned integer (64 bit) value stored in Setting
+ */
 uint64_t
 setting_get_uint (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_UINT)
         return st_set->data.ui_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 64 bit unsigned int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 64 bit unsigned int data
+ * @return     none
+ */
 static void
 setting_set_uint64 (Setting        *st_set,
                     const uint64_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_UINT64);
 
     st_set->data.ui64_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 64 bit unsigned integer value stored in Setting
+ */
 uint64_t
 setting_get_uint64 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_UINT64)
         return st_set->data.ui64_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 32 bit unsigned int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 32 bit unsigned int data
+ * @return     none
+ */
 static void
 setting_set_uint32 (Setting        *st_set,
                     const uint32_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_UINT32);
 
     st_set->data.ui32_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 32 bit unsigned integer value stored in Setting
+ */
 uint32_t
 setting_get_uint32 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_UINT32)
         return st_set->data.ui32_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 16 bit unsigned int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 16 bit unsigned int data
+ * @return     none
+ */
 static void
 setting_set_uint16 (Setting        *st_set,
                     const uint16_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_UINT16);
 
     st_set->data.ui16_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 16 bit unsigned integer value stored in Setting
+ */
 uint16_t
 setting_get_uint16 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_UINT16)
         return st_set->data.ui16_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting 8 bit unsigned int data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  i_val   Value of 8 bit unsigned int data
+ * @return     none
+ */
 static void
 setting_set_uint8 (Setting       *st_set,
                    const uint8_t  i_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_UINT8);
 
     st_set->data.ui8_val = i_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get 8 bit unsigned integer value stored in Setting
+ */
 uint8_t
 setting_get_uint8 (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_UINT8)
         return st_set->data.ui8_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting double data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  d_val   Double value
+ * @return     none
+ */
 static void
 setting_set_double (Setting      *st_set,
                     const double  d_val)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_DOUBLE);
 
     st_set->data.d_val = d_val;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get double type value stored in Setting
+ */
 double
 setting_get_double (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return 0;
-
     if (setting_get_type (st_set) == SET_VAL_DOUBLE)
         return st_set->data.d_val;
     else
         return 0;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting string data value
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  s_str   String data to set
+ * @return     none
+ */
 static void
 setting_set_string (Setting    *st_set,
                     const char *s_str)
 {
-    if (st_set == NULL || s_str == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_STRING);
 
     st_set->data.s_val = str_dup (s_str);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get text string stored in Setting
+ */
 const char *
 setting_get_string (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return NULL;
-
     if (setting_get_type (st_set) == SET_VAL_STRING)
         return (const char *) st_set->data.s_val;
     else
         return NULL;
 }
 /*----------------------------------------------------------------------------*/
-void
+/**
+ * @brief  Set Setting name
+ *
+ * @param[out] st_set  Setting object
+ * @param[in]  s_str   String name to set
+ * @return     none
+ */
+static void
 setting_set_name (Setting    *st_set,
                   const char *s_str)
 {
-    if (st_set == NULL || s_str == NULL)
-        return;
-
     st_set->s_name = str_dup (s_str);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get Setting object's name string
+ */
 const char *
 setting_get_name (const Setting *st_set)
 {
-    if (st_set == NULL)
-        return NULL;
-
     return (const char *) st_set->s_name;
 }
 /*----------------------------------------------------------------------------*/
-void
+/**
+ * @brief  Set Setting type as array
+ *
+ * @param[out] st_set  Setting object
+ * @return     none
+ */
+static void
 setting_set_array (Setting *st_set)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_type (st_set, SET_VAL_ARRAY);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Assing Setting to an array with name s_name
+ */
 void
 setting_assign_to_array (Setting    *st_set,
                          const char *s_name)
 {
-    if (st_set == NULL || s_name == NULL)
-        return;
-
     if (strcmp (s_name, "") == 0)
         setting_set_owner_id (st_set, 0);
     else
-        setting_set_owner_id (st_set, hash (s_name));
+        setting_set_owner_id (st_set, setting_hashfun (s_name));
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove setting from array, setting will stay a normal setting
+ */
 void
-setting_remove_from_array (Setting *st_set)
+setting_reset_array (Setting *st_set)
 {
-    if (st_set == NULL)
-        return;
-
     setting_set_owner_id (st_set, 0);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Copy data from one Setting object to another
+ *
+ * @param[out] st_dest  Destination Setting object
+ * @param[in]  st_src   Source Setting object
+ * @return     none
+ */
 static void
 setting_copy2 (Setting       *st_dest,
                const Setting *st_src)
 {
-    if (st_dest == NULL || st_src == NULL)
-        return;
-
     setting_init (st_dest);
     st_dest->s_name     = str_dup (st_src->s_name);
     st_dest->i_id       = st_src->i_id;
@@ -550,14 +616,14 @@ setting_copy2 (Setting       *st_dest,
     }
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Duplicates a Setting
+ */
 Setting *
 setting_copy (const Setting *st_src)
 {
     Setting *st_ret;
 
-    if (st_src == NULL)
-        return NULL;
-
     st_ret = calloc (1, sizeof (Setting));
 
     if (st_ret == NULL)
@@ -570,107 +636,17 @@ setting_copy (const Setting *st_src)
     return st_ret;
 }
 /*----------------------------------------------------------------------------*/
-void
-setting_print (const Setting *st_set)
-{
-    if (st_set == NULL)
-        return;
-
-    switch (st_set->v_type) {
-        case SET_VAL_INT:
-            printf ("int, val=%ld, n=%s, oid=%ld\n",
-                    setting_get_int (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_UINT:
-            printf ("uint, val=%ld, n=%s, oid=%ld\n",
-                    setting_get_uint (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_INT64:
-            printf ("int64, val=%ld, n=%s, oid=%ld\n",
-                    setting_get_int64 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_UINT64:
-            printf ("uint64, val=%ld, n=%s, oid=%ld\n",
-                    setting_get_uint64 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_INT32:
-            printf ("int32, val=%d, n=%s, oid=%ld\n",
-                    setting_get_int32 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_UINT32:
-            printf ("uint32, val=%d, n=%s, oid=%ld\n",
-                    setting_get_uint32 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_INT16:
-            printf ("int16, val=%d, n=%s, oid=%ld\n",
-                    setting_get_int16 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_UINT16:
-            printf ("uint16, val=%d, n=%s, oid=%ld\n",
-                    setting_get_uint16 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_INT8:
-            printf ("int8, val=%d, n=%s, oid=%ld\n",
-                    setting_get_int8 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_UINT8:
-            printf ("uint8, val=%d, n=%s, oid=%ld\n",
-                    setting_get_uint8 (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_DOUBLE:
-            printf ("double, val=%f, n=%s, oid=%ld\n",
-                    setting_get_double (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_STRING:
-            printf ("str, val=%s, n=%s, oid=%ld\n",
-                    setting_get_string (st_set),
-                    setting_get_name (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        case SET_VAL_ARRAY:
-            printf ("array, n=%s, id=%ld, oid=%ld\n",
-                    setting_get_name (st_set),
-                    setting_get_id (st_set),
-                    setting_get_owner_id (st_set));
-            break;
-        default:
-            break;
-    }
-}
-/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Create default Setting
+ *
+ * @param[in]  s_name  Setting name
+ * @return     New Setting or null
+ */
 static Setting *
 setting_create_default (const char *s_name)
 {
     Setting *st_ret;
 
-    if (s_name == NULL)
-        return NULL;
-
-    if (strcmp (s_name, "") == 0)
-        return NULL;
-
     st_ret = calloc (1, sizeof (Setting));
 
     if (st_ret == NULL)
@@ -680,7 +656,7 @@ setting_create_default (const char *s_name)
 
     setting_set_name (st_ret, s_name);
 
-    setting_set_id (st_ret, hash (s_name));
+    setting_set_id (st_ret, setting_hashfun (s_name));
 
     return st_ret;
 }
@@ -870,6 +846,98 @@ setting_new_array (const char *s_name)
 
     return st_ret;
 }
+#ifdef DEBUG
 /*----------------------------------------------------------------------------*/
+/*
+ * @brief  Print setting info
+ */
+void
+setting_print (const Setting *st_set)
+{
+    switch (st_set->v_type) {
+        case SET_VAL_INT:
+            printf ("int, val=%ld, n=%s, oid=%d\n",
+                    setting_get_int (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_UINT:
+            printf ("uint, val=%ld, n=%s, oid=%d\n",
+                    setting_get_uint (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_INT64:
+            printf ("int64, val=%ld, n=%s, oid=%d\n",
+                    setting_get_int64 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_UINT64:
+            printf ("uint64, val=%ld, n=%s, oid=%d\n",
+                    setting_get_uint64 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_INT32:
+            printf ("int32, val=%d, n=%s, oid=%d\n",
+                    setting_get_int32 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_UINT32:
+            printf ("uint32, val=%d, n=%s, oid=%d\n",
+                    setting_get_uint32 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_INT16:
+            printf ("int16, val=%d, n=%s, oid=%d\n",
+                    setting_get_int16 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_UINT16:
+            printf ("uint16, val=%d, n=%s, oid=%d\n",
+                    setting_get_uint16 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_INT8:
+            printf ("int8, val=%d, n=%s, oid=%d\n",
+                    setting_get_int8 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_UINT8:
+            printf ("uint8, val=%d, n=%s, oid=%d\n",
+                    setting_get_uint8 (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_DOUBLE:
+            printf ("double, val=%f, n=%s, oid=%d\n",
+                    setting_get_double (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_STRING:
+            printf ("str, val=%s, n=%s, oid=%d\n",
+                    setting_get_string (st_set),
+                    setting_get_name (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        case SET_VAL_ARRAY:
+            printf ("array, n=%s, id=%d, oid=%d\n",
+                    setting_get_name (st_set),
+                    setting_get_id (st_set),
+                    setting_get_owner_id (st_set));
+            break;
+        default:
+            break;
+    }
+}
+/*----------------------------------------------------------------------------*/
+#endif
 
 
