@@ -55,37 +55,83 @@ SetValType {
 } SetValType;
 /*----------------------------------------------------------------------------*/
 /**
+ * @struct Setting
+ *
  * @brief  Setting structure 
+ *
+ * @var   Setting::v_type
+ * @brief Type of setting
+ *
+ * @var   Setting::s_name
+ * @brief Name of setting, it must be longer than 2 letters because of hash
+ *        function (could make not unique results for smaller strings).
+ *
+ * @var   Setting::i_id
+ * @brief Setting's id
+ *
+ * @var   Setting::i_owner_id
+ * @brief Setting's owner id
+ *
+ * @var   Setting::data
+ * @brief Struncture with setting value
+ *
+ * @union data_t
+ * @brief Setting's data values
+ *
+ * @var   data_t::i_val
+ * @brief Integer value
+ * @var   data_t::i64_val
+ * @brief 64 bit integer value
+ * @var   data_t::i32_val
+ * @brief 32 bit integer value
+ * @var   data_t::i16_val
+ * @brief 16 bit integer value
+ * @var   data_t::i8_val
+ * @brief 8 bit integer value
+ * @var   data_t::ui_val
+ * @brief Unsigned integer value
+ * @var   data_t::ui64_val
+ * @brief 64 bit unsigned integer value
+ * @var   data_t::ui32_val
+ * @brief 32 bit unsigned integer value
+ * @var   data_t::ui16_val
+ * @brief 16 bit unsigned integer value
+ * @var   data_t::ui8_val
+ * @brief 8 bit unsigned integer value
+ * @var   data_t::d_val
+ * @brief Double type number value
+ * @var   data_t::s_val
+ * @brief String value
  */
 typedef struct 
 Setting {
-    SetValType v_type;     /**< Type of setting */
-    char *s_name;          /**< Setting name */
-    uint64_t i_id;         /**< Setting id */
-    uint64_t i_owner_id;   /**< Setting owner id */
-    union {
-        int64_t  i_val;    /**< Value for integer (64 bit) */
-        int64_t  i64_val;  /**< Value for 64 bit integer */
-        int32_t  i32_val;  /**< Value for 32 bit integer */
-        int16_t  i16_val;  /**< Value for 16 bit integer */
-        int8_t   i8_val;   /**< Value for 8 bit integer */
-        uint64_t ui_val;   /**< Value for unsigned integer (64 bit) */
-        uint64_t ui64_val; /**< Value for 64 bit unsigned integer */
-        uint32_t ui32_val; /**< Value for 32 bit unsigned integer */
-        uint16_t ui16_val; /**< Value for 16 bit unsigned integer */
-        uint8_t  ui8_val;  /**< Value for 8 bit unsigned integer */
-        double   d_val;    /**< Value for double */
-        char    *s_val;    /**< Value for string */
+    SetValType  v_type;
+    char       *s_name;
+    uint32_t    i_id;
+    uint32_t    i_owner_id;
+    union data_t {
+        int64_t   i_val;
+        int64_t   i64_val;
+        int32_t   i32_val;
+        int16_t   i16_val;
+        int8_t    i8_val;
+        uint64_t  ui_val;
+        uint64_t  ui64_val;
+        uint32_t  ui32_val;
+        uint16_t  ui16_val;
+        uint8_t   ui8_val;
+        double    d_val;
+        char     *s_val;
     } data; 
 } Setting;
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Calls hash function
+ * @brief  Calls hash function djb2
  *
- * @param[in]  s_str  String to count hash
+ * @param[in]  str  String to count hash
  * @return     Calculated hash value
  */
-uint64_t setting_hashfun (const char *s_str);
+uint32_t setting_hashfun (const char *str);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Free Setting object
@@ -96,22 +142,22 @@ uint64_t setting_hashfun (const char *s_str);
 void setting_free (Setting *st_set);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  const char * setting_get_name (const Setting *st_set)
+ * @fn         const char * setting_get_name (const Setting *st_set)
  * @brief      Get Setting object's name string
  * @param[in]  st_set  Setting object
  * @return     Name string or null if wrong data passed to function
  *
- * @fn  SetValType setting_get_type (const Setting *st_set)
- * @brief      Get type of Setting object value
+ * @fn         SetValType setting_get_type (const Setting *st_set)
+ * @brief      Get the type of Setting
  * @param[in]  st_set  Setting object
- * @return     Type of Setting value
+ * @return     Type of Setting
  *
- * @fn  uint64_t setting_get_id (const Setting *st_set)
- * @brief      Get Setting object's id number
+ * @fn         uint32_t setting_get_id (const Setting *st_set)
+ * @brief      Get Setting id number
  * @param[in]  st_set  Setting object
  * @return     Id number
  *
- * @fn  uint64_t setting_get_owner_id (const Setting *st_set)
+ * @fn         uint32_t setting_get_owner_id (const Setting *st_set)
  * @brief      Get Setting object's owner id number
  * @param[in]  st_set  Setting object
  * @return     Owner id number
@@ -121,13 +167,13 @@ const char * setting_get_name     (const Setting *st_set);
 
 SetValType   setting_get_type     (const Setting *st_set);
 
-uint64_t     setting_get_id       (const Setting *st_set);
+uint32_t     setting_get_id       (const Setting *st_set);
 
-uint64_t     setting_get_owner_id (const Setting *st_set);
+uint32_t     setting_get_owner_id (const Setting *st_set);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  int64_t setting_get_int (const Setting *st_set)
- * @brief      Get integer value stored in Setting object
+ * @fn         int64_t setting_get_int (const Setting *st_set)
+ * @brief      Get integer value stored in Setting
  *
  * Function gets standard integer value, without type.
  * It is set to hold and return 64 bit integer value.
@@ -135,58 +181,58 @@ uint64_t     setting_get_owner_id (const Setting *st_set);
  * @param[in]  st_set  Setting object
  * @return     64 bit integer or 0 if incorrect type to get
  *
- * @fn  int64_t setting_get_int64 (const Setting *st_set)
- * @brief      Get 64 bit integer value stored in Setting object
+ * @fn         int64_t setting_get_int64 (const Setting *st_set)
+ * @brief      Get 64 bit integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     64 bit integer or 0 if incorrect type to get
  *
- * @fn  int32_t setting_get_int32 (const Setting *st_set)
- * @brief      Get 32 bit integer value stored in Setting object
+ * @fn         int32_t setting_get_int32 (const Setting *st_set)
+ * @brief      Get 32 bit integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     32 bit integer or 0 if incorrect type to get
  *
  * @fn  int16_t setting_get_int16 (const Setting *st_set)
- * @brief      Get 16 bit integer value stored in Setting object
+ * @brief      Get 16 bit integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     16 bit integer or 0 if incorrect type to get
  *
  * @fn  int8_t setting_get_int8 (const Setting *st_set)
- * @brief      Get 8 bit integer value stored in Setting object
+ * @brief      Get 8 bit integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     8 bit integer or 0 if incorrect type to get
  *
- * @fn  uint64_t setting_get_uint (const Setting *st_set)
- * @brief      Get unsigned integer (64 bit) value stored in Setting object
+ * @fn         uint64_t setting_get_uint (const Setting *st_set)
+ * @brief      Get unsigned integer (64 bit) value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     Unsigned integer (64 bit) or 0 if incorrect type to get
  *
- * @fn  uint64_t setting_get_uint64 (const Setting *st_set)
- * @brief      Get 64 bit unsigned integer value stored in Setting object
+ * @fn         uint64_t setting_get_uint64 (const Setting *st_set)
+ * @brief      Get 64 bit unsigned integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     64 bit unsigned integer or 0 if incorrect type to get
  *
- * @fn  uint32_t setting_get_uint32 (const Setting *st_set)
- * @brief      Get 32 bit unsigned integer value stored in Setting object
+ * @fn         uint32_t setting_get_uint32 (const Setting *st_set)
+ * @brief      Get 32 bit unsigned integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     32 bit unsigned integer or 0 if incorrect type to get
  *
- * @fn  uint16_t setting_get_uint16 (const Setting *st_set)
- * @brief      Get 16 bit unsigned integer value stored in Setting object
+ * @fn         uint16_t setting_get_uint16 (const Setting *st_set)
+ * @brief      Get 16 bit unsigned integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     16 bit unsigned integer or 0 if incorrect type to get
  *
- * @fn  uint8_t setting_get_uint8 (const Setting *st_set)
- * @brief      Get 8 bit unsigned integer value stored in Setting object
+ * @fn         uint8_t setting_get_uint8 (const Setting *st_set)
+ * @brief      Get 8 bit unsigned integer value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     8 bit unsigned integer or 0 if incorrect type to get
  *
- * @fn  double setting_get_double (const Setting *st_set)
- * @brief      Get double type value stored in Setting object
+ * @fn         double setting_get_double (const Setting *st_set)
+ * @brief      Get double type value stored in Setting
  * @param[in]  st_set  Setting object
  * @return     Double value or 0 if incorrect type to get
  *
- * @fn  const char * setting_get_string (const Setting *st_set)
- * @brief      Get text string stored in Setting object
+ * @fn         const char * setting_get_string (const Setting *st_set)
+ * @brief      Get text string stored in Setting
  * @param[in]  st_set  Setting object
  * @return     String or null if incorrect type to get
  */
@@ -216,37 +262,38 @@ double       setting_get_double (const Setting *st_set);
 const char * setting_get_string (const Setting *st_set);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  void setting_assign_to_array (Setting *st_set, const char *s_name)
- * @brief       Assing Setting to an array with name s_name
- * @param[out]  st_set  Setting object
- * @param[in]   s_name  Name of array
- * @return      none
+ * @fn         void setting_assign_to_array (Setting    *st_set,
+ *                                           const char *s_name)
+ * @brief      Assing Setting to an array with name s_name
+ * @param[out] st_set  Setting object
+ * @param[in]  s_name  Name of array
+ * @return     none
  *
- * @fn  void setting_remove_from_array (Setting *st_set)
- * @brief       Remove setting from array, setting will stay a normal setting
- *              not assigned to any array
- * @param[out]  st_set  Setting object
- * @return      none
+ * @fn         void setting_reset_array (Setting *st_set)
+ * @brief      Remove setting from array, setting will stay a normal setting
+ *             not assigned to any array
+ * @param[out] st_set  Setting object
+ * @return     none
  */
 /*----------------------------------------------------------------------------*/
-void setting_assign_to_array   (Setting    *st_set,
-                                const char *s_name);
+void setting_assign_to_array  (Setting    *st_set,
+                               const char *s_name);
 
-void setting_remove_from_array (Setting    *st_set);
+void setting_reset_array      (Setting    *st_set);
 /*----------------------------------------------------------------------------*/
 /**
  * @fn  Setting * setting_new_int (const int64_t i_val, const char *s_name)
  * @brief      Create new Setting object for an integer (64 bit), set its
  *             value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_uint (const uint64_t i_val, const char *s_name)
  * @brief      Create new Setting object for an unsigned integer (64 bit),
  *             set its value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_int64 (const int64_t i_val, const char *s_name)
@@ -260,69 +307,69 @@ void setting_remove_from_array (Setting    *st_set);
  * @brief      Create new Setting object for 64 bit unsigned integer, set its
  *             value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_int32 (const int32_t i_val, const char *s_name)
  * @brief      Create new Setting object for 32 bit integer, set its value to
  *             i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_uint32 (const uint32_t i_val, const char *s_name)
  * @brief      Create new Setting object for 32 bit unsigned integer, set its
  *             value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_int16 (const int16_t i_val, const char *s_name)
  * @brief      Create new Setting object for 16 bit integer, set its value to
  *             i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_uint16 (const uint16_t i_val, const char *s_name)
  * @brief      Create new Setting object for 16 bit unsigned integer, set its
  *             value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_int8 (const int8_t i_val, const char *s_name)
  * @brief      Create new Setting object for 8 bit integer, set its value to
  *             i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_uint8 (const uint8_t i_val, const char *s_name)
  * @brief      Create new Setting object for 8 bit unsigned integer, set its
  *             value to i_val and name to s_name.
  * @param[in]  i_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_double (const double d_val, const char *s_name)
  * @brief      Create new Setting object for a double, set its value to d_val
  *             and name to s_name.
  * @param[in]  d_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_string (const char *s_val, const char *s_name)
  * @brief      Create new Setting object for a string, set its value to s_val
  *             and name to s_name.
  * @param[in]  s_val  Value to store in setting
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  *
  * @fn  Setting * setting_new_array (const char *s_name)
  * @brief      Create new Setting object, set it to be an array type and its
  *             name to s_name.
- * @param[in]  s_name  Name of the setting
+ * @param[in]  s_name  Name of the setting (should be longer than 2 letters)
  * @return     New Setting object
  */
 /*----------------------------------------------------------------------------*/
@@ -365,13 +412,13 @@ Setting * setting_new_string (const char      *s_val,
 Setting * setting_new_array  (const char      *s_name);
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Get a copy of setting
+ * @brief  Duplicates a Setting
  *
- * @param[out]  st_src  Setting object to copy
- * @return      Duplicated setting or null if could not allocate or wrong
- *              data passed
+ * @param[in]  st_src  Source Setting object
+ * @return     New copy of Setting or null
  */
 Setting * setting_copy (const Setting *st_src);
+#ifdef DEBUG
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Print setting info
@@ -382,4 +429,5 @@ Setting * setting_copy (const Setting *st_src);
 void setting_print (const Setting *st_set);
 /*----------------------------------------------------------------------------*/
 #endif
+#endif
 
