@@ -18,7 +18,7 @@
  * along with Wall Changer.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @brief  SettList structure and functions
- * 
+ *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #include <stdlib.h>
@@ -39,21 +39,48 @@ static void stlist_init (SettList *st_list);
  *
  * @param[out]  st_list  SettList list of settings
  * @param[in]   ul_size  Size to reserve
- * @return      Reserve result 0 if OK, 1 if error occurred
+ * @return      Reserve result
  */
 static int stlist_reserve (SettList     *st_list,
                            const size_t  ul_size);
 /*----------------------------------------------------------------------------*/
 /**
+ * @brief     Get position of setting with specified id
+ *
+ * @param[in] st_list  SettList list of settings
+ * @param[in] ui_id    Setting id number
+ * @return    Position in list or -1 if not found
+ */
+static int32_t stlist_get_setting_with_id_pos (const SettList *st_list,
+                                               uint32_t        ui_id);
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn  SettList * stlist_get_settings_owned_by (const SettList *st_list,
+ *                                               const uint32_t  ui_oid)
  * @brief  Get list of Setting objects owned by array with owner id ui_oid
  *
  * @param[out]  st_list  SettList list of settings
  * @param[in]   ui_oid   Id of owner array
  * @return      SettList list of Setting objects
+ *
+ * @fn  SettList * stlist_get_settings_owned_by_p (const SettList *st_list,
+                                                   const uint32_t  ui_oid)
+ * @brief  Get list of pointers to Setting objects owned by array with owner
+ *         id ui_oid
+ * @param[in]  st_list  SettList list of settings
+ * @param[in]  ui_oid   Id of owner array
+ * @return     SettList list of pointers to Setting objects
  */
-static SettList * stlist_get_settings_owned_by (const SettList *st_list,
-                                                const uint64_t  ui_oid);
 /*----------------------------------------------------------------------------*/
+static SettList * stlist_get_settings_owned_by   (const SettList *st_list,
+                                                  const uint32_t  ui_oid);
+
+static SettList * stlist_get_settings_owned_by_p (const SettList *st_list,
+                                                  const uint32_t  ui_oid);
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  SettList initialization
+ */
 static void
 stlist_init (SettList *st_list)
 {
@@ -61,6 +88,9 @@ stlist_init (SettList *st_list)
     st_list->st_setting = NULL;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Create new empty list for settings
+ */
 SettList *
 stlist_new_list (void)
 {
@@ -77,7 +107,7 @@ stlist_new_list (void)
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Reserve space for Setting objects in SettList
+ * @brief      Reserve space for Setting objects in SettList
  */
 static int
 stlist_reserve (SettList     *st_list,
@@ -86,9 +116,6 @@ stlist_reserve (SettList     *st_list,
     Setting **s_tmp = NULL;
     uint32_t  i     = 0;
 
-    if (st_list == NULL)
-        return SET_ER_OK;
-
     /* No need to resie */
     if (st_list->i_cnt == ul_size)
         return SET_ER_OK;
@@ -134,32 +161,44 @@ stlist_reserve (SettList     *st_list,
     return SET_ER_OK;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free SettList list
+ */
 void
 stlist_free (SettList *st_list)
 {
-    if (st_list == NULL)
-        return;
-
     stlist_reserve (st_list, 0);
-
     free (st_list);
 }
 /*----------------------------------------------------------------------------*/
 void
+stlist_free_p (SettList *st_list)
+{
+    free (st_list->st_setting);
+    free (st_list);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Clear SettList list of Setting items
+ */
+void
 stlist_clear (SettList *st_list)
 {
     stlist_reserve (st_list, 0);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get number of settings in list
+ */
 uint32_t
 stlist_get_length (const SettList *st_list)
 {
-    if (st_list == NULL)
-        return 0;
-
     return st_list->i_cnt;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Inserts Settings object to settings list
+ */
 int
 stlist_insert_setting (SettList *st_list,
                        Setting  *st_val)
@@ -167,12 +206,6 @@ stlist_insert_setting (SettList *st_list,
     int     i_res = SET_ER_OK;
     int32_t i_pos = 0;
 
-    if (st_val == NULL)
-        return SET_ER_OK;
-
-    if (setting_get_name (st_val) == NULL)
-        return SET_ER_OK;
-
     i_pos = stlist_get_setting_pos (st_list,
                                     setting_get_name (st_val));
     if (i_pos >= 0) {
@@ -193,6 +226,9 @@ stlist_insert_setting (SettList *st_list,
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Inserts Settings object to array in settings list
+ */
 int
 stlist_insert_setting_to_array (SettList   *st_list,
                                 Setting    *st_val,
@@ -201,9 +237,6 @@ stlist_insert_setting_to_array (SettList   *st_list,
     Setting *st_array;
     int      i_res = SET_ER_OK;
 
-    if (st_list == NULL || st_val == NULL)
-        return SET_ER_OK;
-
     if (s_array_name == NULL || strcmp (s_array_name, "") == 0) {
         i_res = stlist_insert_setting (st_list, st_val);
     }
@@ -223,45 +256,89 @@ stlist_insert_setting_to_array (SettList   *st_list,
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
-int32_t
-stlist_get_setting_pos (const SettList *st_list,
-                        const char     *s_name)
+/**
+ * @brief     Get position of setting with specified id
+ */
+static int32_t
+stlist_get_setting_with_id_pos (const SettList *st_list,
+                                uint32_t        ui_id)
 {
-    Setting  *st_act;
     int32_t   i_pos   = -1;
     uint32_t  ui_cnt  = 0;
-    uint64_t  ui_hash = 0;
     uint32_t  i       = 0;
+    Setting  *st_act;
 
-    if (s_name == NULL || st_list == NULL)
-        return i_pos;
-
-    ui_hash = setting_hashfun (s_name);
     ui_cnt  = stlist_get_length (st_list);
 
     for (i = 0; i < ui_cnt; ++i) {
+
         st_act = stlist_get_setting_at_pos (st_list, i);
-        if (st_act != NULL && setting_get_id (st_act) == ui_hash) {
+
+        if (st_act != NULL && setting_get_id (st_act) == ui_id) {
             i_pos = (int32_t) i;
-            break;   
+            break;
         }
     }
     return i_pos;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get position of setting with name s_name on list
+ */
+int32_t
+stlist_get_setting_pos (const SettList *st_list,
+                        const char     *s_name)
+{
+    int32_t   i_pos   = -1;
+    uint32_t  ui_hash = 0;
+
+    ui_hash = setting_hashfun (s_name);
+
+    i_pos = stlist_get_setting_with_id_pos (st_list, ui_hash);
+
+    return i_pos;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get position on list of setting with string type and value s_val
+ */
+int32_t
+stlist_get_setting_val_str_pos (const SettList *st_list,
+                                const char     *s_val)
+{
+    Setting *st_sett;
+    uint32_t ui_cnt = stlist_get_length (st_list);
+
+    for (uint32_t i = 0; i < ui_cnt; ++i) {
+
+        st_sett = stlist_get_setting_at_pos (st_list, i);
+
+        if (setting_get_type (st_sett) == SET_VAL_STRING) {
+
+            if (strcmp (s_val, setting_get_string (st_sett)) == 0) {
+                return (int32_t) i;
+            }
+        }
+    }
+    return -1;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get pointer to Setting object at given position in SettList
+ */
 Setting *
 stlist_get_setting_at_pos (const SettList *st_list,
                            const uint32_t  ui_pos)
 {
-    if (st_list == NULL)
-        return NULL;
-
-    if (ui_pos > st_list->i_cnt - 1) 
+    if (ui_pos >= st_list->i_cnt) 
         return NULL;
 
     return st_list->st_setting[ui_pos];
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get pointer to Setting object with name provided in s_name
+ */
 Setting *
 stlist_get_setting_with_name (const SettList *st_list,
                               const char     *s_name)
@@ -269,9 +346,6 @@ stlist_get_setting_with_name (const SettList *st_list,
     Setting *st_ret;
     int32_t  i_pos = 0;
 
-    if (st_list == NULL || s_name == NULL)
-        return NULL;
-
     if (strcmp (s_name, "") == 0)
         return NULL;
 
@@ -286,16 +360,56 @@ stlist_get_setting_with_name (const SettList *st_list,
     return st_ret;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get list of pointers to Setting objects owned by array with owner
+ *         id ui_oid
+ */
 static SettList *
-stlist_get_settings_owned_by (const SettList *st_list,
-                              const uint64_t  ui_oid) 
+stlist_get_settings_owned_by_p (const SettList *st_list,
+                                const uint32_t  ui_oid) 
 {
     SettList *st_res;
-    Setting *st_val;
-    uint32_t ui_cnt     = 0;
-    uint64_t ui_set_oid = 0;
-    int      i_res      = 0;
-    uint32_t i          = 0;
+    Setting  *st_val;
+    uint32_t  ui_cnt     = 0;
+    uint32_t  ui_set_oid = 0;
+    int       i_res      = 0;
+    uint32_t  i          = 0;
+
+    st_res = stlist_new_list ();
+
+    ui_cnt = stlist_get_length (st_list);
+
+    for (i = 0; i < ui_cnt; ++i) {
+
+        ui_set_oid = setting_get_owner_id (st_list->st_setting[i]);
+
+        if (ui_set_oid == ui_oid) {
+
+            st_val = st_list->st_setting[i];
+
+            i_res = stlist_insert_setting (st_res, st_val);
+            if (i_res != SET_ER_OK) {
+                stlist_free (st_res);
+                return NULL;
+            }
+        }
+    }
+    return st_res;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get list of Setting objects owned by array with owner id ui_oid
+ */
+static SettList *
+stlist_get_settings_owned_by (const SettList *st_list,
+                              const uint32_t  ui_oid) 
+{
+    SettList *st_res;
+    Setting  *st_val;
+    uint32_t  ui_cnt     = 0;
+    uint32_t  ui_set_oid = 0;
+    int       i_res      = 0;
+    uint32_t  i          = 0;
 
     st_res = stlist_new_list ();
 
@@ -319,16 +433,16 @@ stlist_get_settings_owned_by (const SettList *st_list,
     return st_res;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get SettList list of Setting objects stored in array.
+ */
 SettList *
 stlist_get_settings_in_array_name (const SettList *st_list,
                                    const char     *s_name) 
 {
     SettList *st_res;
     Setting  *st_array;
-    uint64_t  ui_array_id = 0;
-
-    if (st_list == NULL || s_name == NULL)
-        return NULL;
+    uint32_t  ui_array_id = 0;
 
     if (strcmp (s_name, "") == 0) {
         ui_array_id = 0;
@@ -349,15 +463,45 @@ stlist_get_settings_in_array_name (const SettList *st_list,
     return st_res;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get SettList list of pointers to Setting objects stored in array.
+ */
+SettList *
+stlist_get_settings_in_array_name_p (const SettList *st_list,
+                                     const char     *s_name) 
+{
+    SettList *st_res;
+    Setting  *st_array;
+    uint32_t  ui_array_id = 0;
+
+    if (strcmp (s_name, "") == 0) {
+        ui_array_id = 0;
+    }
+    else {
+        st_array = stlist_get_setting_with_name (st_list, s_name);
+        if (st_array == NULL)
+            return NULL;
+
+        if (setting_get_type (st_array) != SET_VAL_ARRAY)
+            return NULL;
+
+        ui_array_id = setting_get_id (st_array);
+    }
+
+    st_res = stlist_get_settings_owned_by_p (st_list, ui_array_id);
+
+    return st_res;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get SettList list of Setting objects stored in array.
+ */
 SettList *
 stlist_get_settings_in_array_obj (const SettList *st_list,
                                   const Setting  *st_array)
 {
     SettList *st_res;
 
-    if (st_list == NULL || st_array == NULL)
-        return NULL;
-
     if (setting_get_type (st_array) != SET_VAL_ARRAY)
         return NULL;
 
@@ -366,12 +510,119 @@ stlist_get_settings_in_array_obj (const SettList *st_list,
     return st_res;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get SettList list of pointers to Setting objects stored in array.
+ */
+SettList *
+stlist_get_settings_in_array_obj_p (const SettList *st_list,
+                                    const Setting  *st_array)
+{
+    SettList *st_res;
+
+    if (setting_get_type (st_array) != SET_VAL_ARRAY)
+        return NULL;
+
+    st_res = stlist_get_settings_owned_by_p (st_list,
+                                             setting_get_id (st_array));
+
+    return st_res;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get Setting objects (vals and arrays) stord in SettList top level.
+ */
 SettList *
 stlist_get_settings_main (const SettList *st_list) 
 {
     return stlist_get_settings_owned_by (st_list, 0);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get pointers to Setting objects (vals and arrays) stord in
+ *         SettList top level.
+ */
+SettList *
+stlist_get_settings_main_p (const SettList *st_list) 
+{
+    return stlist_get_settings_owned_by_p (st_list, 0);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove Settings from list at specified position
+ */
+int
+stlist_remove_setting_at_pos (SettList *st_list,
+                              uint32_t  ui_pos)
+{
+    int      i_res = SET_ER_OK;
+    uint32_t ui_len = 0;
+    Setting *st_set;
+
+    ui_len = stlist_get_length (st_list);
+
+    if (ui_pos >= ui_len)
+        return SET_ER_NO_SET;
+
+    st_set = stlist_get_setting_at_pos (st_list, ui_pos);
+
+    for (uint32_t i = ui_pos; i < ui_len - 1; ++i) {
+        st_list->st_setting[i] = st_list->st_setting[i + 1];
+    }
+
+    st_list->st_setting[ui_len - 1] = st_set;
+
+    i_res = stlist_reserve (st_list, ui_len - 1);
+
+    return i_res;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove Settings from list 
+ */
+int
+stlist_remove_setting (SettList *st_list,
+                       Setting  *st_val)
+{
+    int      i_res   = SET_ER_OK;
+    int32_t  i_pos   = 0;
+    uint32_t ui_hash = 0;
+
+    ui_hash = setting_get_id (st_val);
+
+    i_pos = stlist_get_setting_with_id_pos (st_list, ui_hash);
+
+    if (i_pos == -1)
+        return SET_ER_NO_SET;
+
+    i_res = stlist_remove_setting_at_pos (st_list, (uint32_t) i_pos);
+
+    return i_res;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove Settings with specified name from list 
+ */
+int
+stlist_remove_setting_with_name (SettList   *st_list,
+                                 const char *s_name)
+{
+    int      i_res   = SET_ER_OK;
+    int32_t  i_pos   = 0;
+    uint32_t ui_hash = 0;
+
+    ui_hash = setting_hashfun (s_name);
+
+    i_pos = stlist_get_setting_with_id_pos (st_list, ui_hash);
+
+    if (i_pos == -1)
+        return SET_ER_NO_SET;
+
+    i_res = stlist_remove_setting_at_pos (st_list, (uint32_t) i_pos);
+
+    return i_res;
+}
+/*----------------------------------------------------------------------------*/
+#ifdef DEBUG
 /**
  * @brief  Print content of SettList list
  */
@@ -381,9 +632,6 @@ stlist_print_content (const SettList *st_list)
     uint32_t ui_cnt = 0;
     uint32_t i      = 0;
 
-    if (st_list == NULL)
-        return;
-
     ui_cnt = stlist_get_length (st_list);
 
     for (i = 0; i < ui_cnt; ++i) {
@@ -391,4 +639,5 @@ stlist_print_content (const SettList *st_list)
     }
 }
 /*----------------------------------------------------------------------------*/
+#endif
 
