@@ -26,6 +26,7 @@
 
 #include "wallsett.h"
 #include "settlist.h"
+//#include "flist.h"
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Settings enum values
@@ -49,6 +50,14 @@ enum {
  */
 const char * get_setting_name (const int i_val);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check SettList values set default ones if needed.
+ *
+ * @param[in]  st_list  SettList list of settings
+ * @return     none
+ */
+void settlist_check_defaults (SettList *st_list);
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Read program settings. 
  *
@@ -95,15 +104,15 @@ int settings_update_window_size (const int   i_w,
                                  const char *s_cfg_file);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  int settings_check_update (const SettList  *st_list,
- *                                 const char      *s_fname,
- *                                 char           **s_out_buff)
+ * @fn  char * settings_check_update (const SettList   *st_list,
+                                      const char       *s_fname,
+                                      int              *i_err)
  * @brief      Check if settings in SettList are an update to settings
  *             stored in settings file.
  * @param[in]  st_list     List of settings
  * @param[in]  s_fname     Config file name
- * @param[out] s_out_buff  Buffer to write data
- * @return     ERR_OK or error code
+ * @param[out] i_err       Error output
+ * @return     String with updated settings or null if there is no update.
  *
  * @fn  int settings_update_file (const char *s_buff,
  *                                const char *s_fname)
@@ -121,15 +130,15 @@ int settings_update_window_size (const int   i_w,
  * @return    Saving file status, ERR_OK or error code
  */
 /*----------------------------------------------------------------------------*/
-int settings_check_update      (const SettList   *st_list,
-                                const char       *s_fname,
-                                char            **s_out_buff);
+char * settings_check_update      (const SettList   *st_list,
+                                   const char       *s_fname,
+                                   int              *i_err);
 
-int settings_update_file       (const char       *s_buff,
-                                const char       *s_fname);
+int    settings_update_file       (const char       *s_buff,
+                                   const char       *s_fname);
 
-int settings_check_update_file (const SettList   *st_list,
-                                const char       *s_fname);
+int    settings_check_update_file (const SettList   *st_list,
+                                   const char       *s_fname);
 /*----------------------------------------------------------------------------*/
 #endif
 
