@@ -22,7 +22,7 @@
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #include <stdint.h>
-#include "miscfun.h"
+#include "strfun.h"
 #include "treev.h"
 /*----------------------------------------------------------------------------*/
 /**
@@ -49,8 +49,15 @@
  * @fn  static void treeview_replace_data (GtkWidget *gw_tview,
  *                                         GSList    *gsl_iinfo1)
  * @brief      Replace data in TreeView.
- * @param[out] gw_tview     TreeView in which data should be replaced
- * @param[in]  gsl_iinfo1   List with ImageInfo objects with data.
+ * @param[out] gw_tview    TreeView in which data should be replaced
+ * @param[in]  gsl_iinfo1  List with ImageInfo objects with data.
+ * @return     none
+ *
+ * @fn  static void liststore_add_items (GtkWidget *gw_list,
+ *                                       GSList    *gsl_iinfo1)
+ * @brief  Insert multiple data items to GtkListStore.
+ * @param[out] gw_list     GtkWidget with GtkListStore to insert data
+ * @param[in]  gsl_iinfo1  List with ImageInfo objects with data.
  * @return     none
  */
 /*----------------------------------------------------------------------------*/
@@ -63,6 +70,9 @@ static void liststore_add_item    (GtkWidget       *gw_list,
 
 static void treeview_replace_data (GtkWidget       *gw_tview,
                                    GSList          *gsl_iinfo1);
+
+static void liststore_add_items   (GtkWidget       *gw_list,
+                                   GSList          *gsl_iinfo1);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set data in GtkListStore.
@@ -118,7 +128,7 @@ treeview_replace_data (GtkWidget *gw_tview,
     gsl_iinfo = gsl_iinfo1;
 
     gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
-    gls_list = GTK_LIST_STORE (gtm_model);
+    gls_list  = GTK_LIST_STORE (gtm_model);
 
     ui_icnt = g_slist_length (gsl_iinfo);
     ui_mcnt = (uint32_t) gtk_tree_model_iter_n_children (
@@ -141,7 +151,7 @@ treeview_replace_data (GtkWidget *gw_tview,
 /**
  * @brief  Insert multiple data items to GtkListStore.
  */
-void
+static void
 liststore_add_items (GtkWidget *gw_list,
                      GSList    *gsl_iinfo1)
 {
@@ -157,6 +167,96 @@ liststore_add_items (GtkWidget *gw_list,
     }
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Insert multiple data items to GtkListStore.
+ */
+void
+liststore_add_items_glist (GtkWidget *gw_list,
+                           GList     *gl_files)
+{
+    GList *gl_fl = NULL; /* Temp ItemInfo list */
+
+    gl_fl = gl_files;
+
+    while (gl_fl != NULL) {
+
+        const char *s_fn = (const char *) gl_fl->data;
+
+        ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+
+        if (ii_info != NULL) {
+
+            liststore_add_item (gw_list, ii_info);
+
+            imageinfo_free (ii_info);
+        }
+
+        gl_fl = gl_fl->next;
+    }
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Insert multiple data items to GtkListStore.
+ */
+void
+liststore_add_items_gslist (GtkWidget *gw_list,
+                            GSList    *gl_files)
+{
+    GSList *gl_fl = NULL; /* Temp ItemInfo list */
+
+    gl_fl = gl_files;
+
+    while (gl_fl != NULL) {
+
+        const char *s_fn = (const char *) gl_fl->data;
+
+        ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+
+        if (ii_info != NULL) {
+
+            liststore_add_item (gw_list, ii_info);
+
+            imageinfo_free (ii_info);
+        }
+
+        gl_fl = gl_fl->next;
+    }
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Insert multiple data items to GtkListStore.
+ */
+void
+liststore_add_items_settlist (GtkWidget       *gw_list,
+                              const SettList  *sl_walls)
+{
+    Setting    *st_wall;
+    const char *s_fn      = NULL;
+    uint32_t    ui_cnt    = 0;
+    uint32_t    i         = 0;
+
+    ui_cnt = stlist_get_length (sl_walls);
+
+    for (i = 0; i < ui_cnt; ++i) {
+
+        st_wall = stlist_get_setting_at_pos (sl_walls, i);
+
+        s_fn = setting_get_string (st_wall);
+
+        if (s_fn != NULL) {
+
+            ImageInfo *ii_info = imageinfo_new_from_file (s_fn);
+
+            if (ii_info != NULL) {
+
+                liststore_add_item (gw_list, ii_info);
+
+                imageinfo_free (ii_info);
+            }
+        }
+    }
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get data from GtkTreeModel to ImageInfo object.
  */
@@ -188,9 +288,9 @@ treeview_get_data (GtkWidget *gw_tview)
     ImageInfo    *ii_info;
     GtkTreeIter   gti_iter;
     gboolean      b_res     = FALSE;
-    gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
 
-    b_res = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
+    gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
+    b_res     = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
 
     while (b_res) {
 
@@ -217,8 +317,7 @@ treeview_find_select_item (GtkWidget  *gw_tview,
     const char       *s_val     = NULL;
 
     gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
-
-    b_res = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
+    b_res     = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
 
     while (b_res) {
         gtk_tree_model_get_value(gtm_model, &gti_iter,
@@ -226,7 +325,7 @@ treeview_find_select_item (GtkWidget  *gw_tview,
 
         s_val = (const char*) g_value_get_string(&value);
 
-        if (compare_strings (s_file, s_val) == 0) {
+        if (str_compare (s_file, s_val) == 0) {
             gts_sele = gtk_tree_view_get_selection (GTK_TREE_VIEW (gw_tview));
             gtk_tree_selection_select_iter (gts_sele, &gti_iter);
             break;
@@ -271,8 +370,7 @@ treeview_remove_duplicates (GtkWidget *gw_tview)
     const char     *s_val2    = NULL;
 
     gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (gw_tview));
-
-    b_res = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
+    b_res     = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
 
     while (b_res) {
 
@@ -292,7 +390,7 @@ treeview_remove_duplicates (GtkWidget *gw_tview)
                                      COL_FULL_FILE_NAME, &value2);
             s_val2 = (const char*) g_value_get_string(&value2);
 
-            if (compare_strings (s_val, s_val2) == 0) {
+            if (str_compare (s_val, s_val2) == 0) {
 
                 gtk_list_store_remove (GTK_LIST_STORE (gtm_model), &gti_act);
             }
@@ -319,7 +417,7 @@ treeview_remove_selected (GtkWidget *gw_tview)
     gts_sele  = gtk_tree_view_get_selection (GTK_TREE_VIEW (gw_tview));
     gl_list   = gtk_tree_selection_get_selected_rows (gts_sele, &gtm_model);
 
-    gl_list1 = g_list_last (gl_list);
+    gl_list1  = g_list_last (gl_list);
 
     while (gl_list1 != NULL) {
 
