@@ -23,7 +23,7 @@
 */
 #include <string.h>
 #include <stdlib.h>
-#include "miscfun.h"
+#include "cfgfile.h"
 #include "errs.h"
 #include "wallsett.h"
 /*----------------------------------------------------------------------------*/
@@ -33,17 +33,19 @@
 int
 wallset_init (WallSett *ws_sett)
 {
-    int   i_err            = 0;    /* Return result value */
-    ws_sett->i_chinterval  = 30;   /* Wallpaper change interval */ 
-    ws_sett->i_random      = 0;    /* Random wallpaper change */
-    ws_sett->i_lastsett    = 0;    /* Last used wallpaper setting */
-    ws_sett->s_lastused    = NULL; /* Last used wallpaper file name */
-    ws_sett->s_bgcmd       = NULL; /* Background set command */
+    ws_sett->i_chinterval  = 30;     /* Wallpaper change interval */ 
+    ws_sett->i_random      = 0;      /* Random wallpaper change */
+    ws_sett->i_lastsett    = 0;      /* Last used wallpaper setting */
+    ws_sett->s_lastused    = NULL;   /* Last used wallpaper file name */
+    ws_sett->s_bgcmd       = NULL;   /* Background set command */
+    ws_sett->sl_walls      = NULL;   /* Wallpaper list */
+    int i_err              = ERR_OK; /* Return result value */
+
+    memset (ws_sett->s_cfgfile, 0, sizeof (ws_sett->s_cfgfile));
 
-    flist_init (&ws_sett->fl_files);
     randomm_init (&ws_sett->rm_mem);
-    
-    ws_sett->s_cfgfile = check_config_path_file (&i_err);
+
+    i_err = set_config_file_path (ws_sett->s_cfgfile);
 
     return i_err;
 }
@@ -54,12 +56,8 @@ wallset_init (WallSett *ws_sett)
 void
 wallset_free (WallSett *ws_sett)
 {
-    flist_free (&ws_sett->fl_files);
-    free (ws_sett->s_bgcmd);
-    free (ws_sett->s_cfgfile);
-    free (ws_sett->s_lastused);
-    ws_sett->s_bgcmd = NULL;
-    ws_sett->s_cfgfile = NULL;
+    stlist_free_p (ws_sett->sl_walls);
+    ws_sett->s_bgcmd    = NULL;
     ws_sett->s_lastused = NULL;
 }
 /*----------------------------------------------------------------------------*/
@@ -72,6 +70,25 @@ wallset_get_cfg_fn (const WallSett *ws_sett)
     return (const char*) ws_sett->s_cfgfile;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Sets wallpaper list value.
+ */
+void
+wallset_set_wallpaper_list (WallSett *ws_sett,
+                            SettList *sl_list)
+{
+    ws_sett->sl_walls = sl_list;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get wallpaper list pointer.
+ */
+const SettList *
+wallset_get_wallpaper_list (const WallSett *ws_sett)
+{
+    return (const SettList *) ws_sett->sl_walls;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set using last used wallpaper on start.
  */
@@ -132,25 +149,11 @@ wallset_get_interval (const WallSett *ws_sett)
 /**
  * @brief  Change last used wallpaper file name in program settings. 
  */
-int
+void
 wallset_set_last_used_fn (WallSett   *ws_sett,
                           const char *s_fn)
 {
-    if (s_fn == NULL)
-        return ERR_OK;
-
-    if (compare_strings (s_fn, ws_sett->s_lastused) == 0)
-        return ERR_OK;
-
-    create_resize ((void**) &ws_sett->s_lastused,
-                   strlen (s_fn) + 1,
-                   sizeof (char));
-
-    if (ws_sett->s_lastused != NULL) {
-
-        strcpy (ws_sett->s_lastused, s_fn);
-    }
-    return ERR_OK;
+    ws_sett->s_lastused = s_fn;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -165,23 +168,11 @@ wallset_get_last_used_fn (const WallSett *ws_sett)
 /**
  * @brief  Sets command for setting wallpaper. 
  */
-int
+void
 wallset_set_command (WallSett   *ws_sett,
                      const char *s_cmd)
 {
-    if (s_cmd == NULL)
-        return ERR_OK;
-
-    if (compare_strings (s_cmd, ws_sett->s_bgcmd) == 0)
-        return ERR_OK;
-
-    create_resize ((void**) &ws_sett->s_bgcmd,
-                   strlen (s_cmd) + 1,
-                   sizeof (char));
-
-    strcpy (ws_sett->s_bgcmd, s_cmd);
-
-    return ERR_OK;
+    ws_sett->s_bgcmd = s_cmd;
 }
 /*----------------------------------------------------------------------------*/
 /**
