@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date December 9, 2019
+ * @date December 22, 2019
  *
- * @version 1.3.4
+ * @version 1.3.5
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -36,33 +36,47 @@
 #include "dlgs.h"
 #include "treev.h"
 #include "preview.h"
-#include "flist.h"
+#include "strfun.h"
 #include "errs.h"
-#include "miscfun.h"
-#define APP_NAME "Wall Changer"
-#define APP_VER  "1.3.4"
+#include "cfgfile.h"
+#include "defs.h"
+#include "fdops.h"
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Structore to pass widgets and settings to callback
+ * @struct DialogData
+ *
+ * @brief  Structure to pass widgets and settings to callback
+ *
+ * @var   DialogData::gw_window
+ * @brief Pointer to main config dialog window
+ * @var   DialogData::gw_view
+ * @brief Pointer to TreeView with wallpaper list
+ * @var   DialogData::gw_random
+ * @brief Pointer to CheckBox for selecting random wallpapers
+ * @var   DialogData::gw_lastused
+ * @brief Pointer to CheckBox for restoring last used wallpaper on start
+ * @var   DialogData::gw_command
+ * @brief Pointer to Entry with command to set wallpaper
+ * @var   DialogData::gw_interval
+ * @brief Pointer to CheckBox for selecting wallpaper change interval
+ * @var   DialogData::gw_inter_combo
+ * @brief Pointer to ComboBox for selecting wallpapet change interval
+ * @var   DialogData::s_cfg_file
+ * @brief Array of chars for config file path
  */
 typedef struct
 DialogData {
-    GtkWindow  *gw_window;      /**< App window pointer */
-    GtkWidget  *gw_view;        /**< TreeView file list widget */
-    GtkWidget  *gw_random;      /**< Random background select check box */
-    GtkWidget  *gw_lastused;    /**< Set last used wallpaper check box */
-    GtkWidget  *gw_command;     /**< Set wallpaper command entry */
-    GtkWidget  *gw_interval;    /**< Time interval check button */
-    GtkWidget  *gw_inter_combo; /**< Time interval combo box */
-    char       *s_cfg_file;     /**< Config file string */
+    GtkWindow  *gw_window;       /* App window pointer */
+    GtkWidget  *gw_view;         /* TreeView file list widget */
+    GtkWidget  *gw_random;       /* Random background select check box */
+    GtkWidget  *gw_lastused;     /* Set last used wallpaper check box */
+    GtkWidget  *gw_command;      /* Set wallpaper command entry */
+    GtkWidget  *gw_interval;     /* Time interval check button */
+    GtkWidget  *gw_inter_combo;  /* Time interval combo box */
+    char        s_cfg_file[256]; /* Config file string */
 } DialogData;
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  static void get_pbuf_exts_add_to_flist (FList *fl_exts)
- * @brief      Get list of extensions supported by GdkPixbuf.
- * @param[out] fl_exts  List to put extension in
- * @return     none 
- *
  * @fn  static uint32_t get_wallpaper_ch_interval (const DialogData *dd_data)
  * @brief         Get wallpaper change minutes interval from widgets
  * @param[in,out] dd_data  DialogData object with settings and widget data
@@ -227,8 +241,6 @@ DialogData {
  * @return     none
  */
 /*----------------------------------------------------------------------------*/
-static void        get_pbuf_exts_add_to_flist  (FList             *fl_exts);
-/*----------------------------------------------------------------------------*/
 static uint32_t    get_wallpaper_ch_interval   (const DialogData  *dd_data);
 
 static void        set_wallpaper_ch_interval   (DialogData        *dd_data,
@@ -273,6 +285,9 @@ static void        event_save_settings_pressed (GtkWidget         *widget,
                                                 DialogData        *dd_data);
 
 static void        event_about_app_pressed     (GtkWidget         *widget);
+
+static void        event_interval_changed      (GtkSpinButton     *spin_button,
+                                                DialogData        *dd_data);
 /*----------------------------------------------------------------------------*/
 static void        event_img_list_activated    (GtkTreeView       *tree_view,
                                                 GtkTreePath       *path,
@@ -301,44 +316,6 @@ static void        activate                    (GtkApplication    *app,
 static void        shutdown                    (GtkApplication    *app,
                                                 DialogData        *dd_data);
 /*----------------------------------------------------------------------------*/
-static inline const char *
-get_default_bg_cmd (void) {
-    return "feh --bg-fill";
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Get list of extensions supported by GdkPixbuf.
- */
-static void
-get_pbuf_exts_add_to_flist (FList *fl_exts)
-{
-    GdkPixbufFormat  *gpf          = NULL;
-    GSList           *gsl_formats  = NULL;
-    char            **exts         = NULL;
-    char            **it           = NULL;
-
-    /* Get information aboout image formats supported by GdkPixbuf */
-    gsl_formats = gdk_pixbuf_get_formats();
-
-    while (gsl_formats != NULL) {
-
-        gpf = gsl_formats->data;
-
-        /* Get extension list for current format */
-        exts = gdk_pixbuf_format_get_extensions (gpf);
-
-        for (it = exts; *it != NULL; it++) {
-            /* Insert extension to list */
-            flist_insert_data (fl_exts, *it);
-        }
-        /* Free extensions list */
-        g_strfreev (exts);
-
-        gsl_formats = gsl_formats->next;
-    }
-    g_slist_free (gsl_formats);
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get wallpaper change minutes interval from widgets
  */
@@ -374,7 +351,6 @@ set_wallpaper_ch_interval (DialogData    *dd_data,
         /* If value can be hours set combobox to hours */
         gtk_combo_box_set_active (GTK_COMBO_BOX (dd_data->gw_inter_combo), 1);
 
-        /* Divide inteval value to display by 60 */
         ui_tmp /= 60;
     }
     else {
@@ -394,30 +370,28 @@ get_wallpaper_list (GtkWidget *gw_view,
                     SettList  *st_list)
 {
     ImageInfo  *ii_info;
-    GSList     *gsl_iinfo;
     Setting    *st_sett;
     GSList     *gsl_iinfo1 = NULL; /* List of ImageInfo data */
+    GSList     *gsl_iinfo  = NULL; /* Temp list for data */
     const char *s_val      = NULL; /* Full file path */
     char       *s_name     = NULL; /* Unique name for background file */
     size_t      ul_no      = 0;    /* Number to append to name */
 
     /* get ImageInfo list of TreeView files */
     gsl_iinfo1 = treeview_get_data (gw_view);
-    
+
     gsl_iinfo = gsl_iinfo1;
 
-    if (gsl_iinfo != NULL) {
-        st_sett = setting_new_array (get_setting_name (SETTING_WALL_ARRAY));
-        stlist_insert_setting (st_list, st_sett);
-    }
+    st_sett = setting_new_array (get_setting_name (SETTING_WALL_ARRAY));
+    stlist_insert_setting (st_list, st_sett);
 
     while (gsl_iinfo != NULL) {
 
         ii_info = gsl_iinfo->data;
 
         s_val = ii_info->s_full_path;
-        s_name = string_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
-                                          ul_no++);
+        s_name = str_name_with_number (get_setting_name (SETTING_WALL_ARRAY),
+                                       ul_no++);
 
         st_sett = setting_new_string (s_val, s_name);
 
@@ -437,35 +411,7 @@ static void
 set_wallpaper_list (const SettList *sl_walls,
                     GtkWidget      *gw_view)
 {
-    Setting    *st_wall;
-    ImageInfo  *ii_info;
-    GSList     *gsl_iinfo = NULL;
-    const char *s_fn      = NULL;
-    uint32_t    ui_cnt    = 0;
-    uint32_t    i         = 0;
-
-    if (sl_walls == NULL) 
-        return;
-
-    ui_cnt = stlist_get_length (sl_walls);
-
-    for (i = 0; i < ui_cnt; ++i) {
-
-        st_wall = stlist_get_setting_at_pos (sl_walls, i);
-
-        s_fn = setting_get_string (st_wall);
-        if (s_fn != NULL) {
-
-            ii_info = imageinfo_new_from_file (s_fn);
-            if (ii_info != NULL) {
-                gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
-            }
-        }
-    }
-    /* Add ImageInfo list file data to TreeView */
-    liststore_add_items (gw_view, gsl_iinfo);
-
-    g_slist_free_full (gsl_iinfo, (GDestroyNotify) imageinfo_free);
+    liststore_add_items_settlist (gw_view, sl_walls);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -522,20 +468,16 @@ widgets_set_settings (DialogData     *dd_data,
 {
     Setting  *st_sett;
     SettList *sl_walls;
-    int       i_w = 1024;
-    int       i_h = 768;
+    int       i_w = 0;
+    int       i_h = 0;
 
     /* Set background set command */
     st_sett = stlist_get_setting_with_name (
             st_list, get_setting_name (SETTING_BG_CMD));
-    if (st_sett != NULL && strcmp (setting_get_string (st_sett), "") != 0) {
+    if (st_sett != NULL) {
         gtk_entry_set_text (GTK_ENTRY (dd_data->gw_command),
                             setting_get_string (st_sett));
     }
-    else {
-        gtk_entry_set_text (GTK_ENTRY (dd_data->gw_command),
-                            get_default_bg_cmd ());
-    }
     /* Set last used wallpaper on start setting */
     st_sett = stlist_get_setting_with_name (
             st_list, get_setting_name (SETTING_LAST_USED_OPT));
@@ -557,25 +499,27 @@ widgets_set_settings (DialogData     *dd_data,
                                       (gboolean) setting_get_uint32 (st_sett));
     }
     /* Get wallpaper list and add to treeview */
-    sl_walls = stlist_get_settings_in_array_name (st_list,
+    sl_walls = stlist_get_settings_in_array_name_p (st_list,
             get_setting_name (SETTING_WALL_ARRAY));
 
-    set_wallpaper_list (sl_walls, dd_data->gw_view);
+    if (sl_walls != NULL) {
+        set_wallpaper_list (sl_walls, dd_data->gw_view);
+        stlist_free_p (sl_walls);
+    }
 
     /* Set window dimensions */
     st_sett = stlist_get_setting_with_name (
             st_list, get_setting_name (SETTING_WIN_WIDTH));
     if (st_sett != NULL) {
         i_w = (int) setting_get_uint32 (st_sett);
-        st_sett = stlist_get_setting_with_name (
-                st_list, get_setting_name (SETTING_WIN_HEIGHT));
-        if (st_sett != NULL) {
-            i_h = (int) setting_get_uint32 (st_sett);
-        }
     }
+    st_sett = stlist_get_setting_with_name (
+            st_list, get_setting_name (SETTING_WIN_HEIGHT));
+    if (st_sett != NULL) {
+        i_h = (int) setting_get_uint32 (st_sett);
+    }
+ 
     gtk_window_set_default_size (GTK_WINDOW (dd_data->gw_window), i_w, i_h);
-
-    stlist_free (sl_walls);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -586,19 +530,17 @@ event_add_img_pressed (GtkWidget  *widget,
                        DialogData *dd_data)
 {
     GSList *gsl_files = NULL; /* List with files from dialog */
-    GSList *gsl_iinfo = NULL; /* List with ImageInfo file list */
 
     /* Run image select dialog and get selected files */
     gsl_files = add_images_dialog (dd_data->gw_window);
 
-    /* Convert file list to ImageInfo list */
-    gsl_iinfo = file_paths_to_imageinfo (gsl_files);
+    /* Add items to TreeView */
+    if (gsl_files != NULL) {
 
-    /* Add ImageInfo items to TreeView */
-    liststore_add_items (dd_data->gw_view, gsl_iinfo);
+        liststore_add_items_gslist (dd_data->gw_view, gsl_files);
 
-    g_slist_free_full (gsl_files, g_free);
-    g_slist_free_full (gsl_iinfo, (GDestroyNotify) imageinfo_free);
+        g_slist_free_full (gsl_files, g_free);
+    }
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -608,39 +550,36 @@ static void
 event_add_img_dir_pressed (GtkWidget  *widget,
                            DialogData *dd_data)
 {
-    GSList *gsl_files = NULL; /* List of ImageInfo items to liststore */
-    char   *s_folder  = NULL; /* Selecred directory name */
-    FList   fl_files;         /* Files in directory */
-    FList   fl_exts;          /* List of extensions of supported image types */
-
-    flist_init (&fl_exts);
-    flist_init (&fl_files);
+    char       *s_folder = NULL;  /* Selecred directory name */
+    GList      *gl_files = NULL;  /* Images in directory */
+    GHashTable *gh_exts;          /* List of extensions */
 
     /* Append to list extensions of image types supported by GdkPixbuf */
-    get_pbuf_exts_add_to_flist (&fl_exts);
+    gh_exts = get_pbuf_exts_to_ghash ();
 
     /* Run directory select dialog and get selected directory name */
     s_folder = add_images_folder_dialog (dd_data->gw_window);
 
     if (s_folder != NULL) {
         /* Scan directory for files and append them to file list */
-        get_directory_content_add_to_flist (s_folder, &fl_files);
+        gl_files = get_directory_content_glist (s_folder);
 
-        /* Filter file list of files with extensions that are not
-         * supported by GdkPixbuf */
-        flist_filter_by_extensions_list (&fl_files, &fl_exts);
+        if (gl_files != NULL) {
+            /* Filter file list of files with extensions that are not
+             * supported by GdkPixbuf */
+            gl_files = glist_filter_by_extensions_list (gl_files, gh_exts);
 
-        /* Convert file list to ImageInfo list */
-        gsl_files = flist_to_imageinfo (&fl_files);
+            if (gl_files != NULL) {
+                /* Add items to TreeView */
+                liststore_add_items_glist (dd_data->gw_view, gl_files);
 
-        /* Add ImageInfo items to TreeView */
-        liststore_add_items (dd_data->gw_view, gsl_files);
+                g_list_free_full (gl_files, g_free);
+            }
+        }
 
-        g_slist_free_full (gsl_files, (GDestroyNotify) imageinfo_free);
         g_free (s_folder);
     }
-    flist_free (&fl_files);
-    flist_free (&fl_exts);
+    g_hash_table_destroy (gh_exts);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -706,10 +645,11 @@ event_set_wallpaper_pressed (GtkWidget  *widget,
     GtkTreeIter       gti_iter;
     GList            *gl_list   = NULL;
     const char       *s_cmd     = NULL;
+    int               i_err     = 0;
 
     gtm_model = gtk_tree_view_get_model (GTK_TREE_VIEW (dd_data->gw_view));
-    gts_sele = gtk_tree_view_get_selection (GTK_TREE_VIEW (dd_data->gw_view));
-    gl_list = gtk_tree_selection_get_selected_rows (gts_sele, &gtm_model);
+    gts_sele  = gtk_tree_view_get_selection (GTK_TREE_VIEW (dd_data->gw_view));
+    gl_list   = gtk_tree_selection_get_selected_rows (gts_sele, &gtm_model);
 
     if (gl_list == NULL)
         return;
@@ -719,11 +659,11 @@ event_set_wallpaper_pressed (GtkWidget  *widget,
         ii_info = treemodel_get_data (gtm_model, gti_iter);
         s_cmd = gtk_entry_get_text (GTK_ENTRY (dd_data->gw_command));
 
-        if (wallpaper_dialog_set (s_cmd,
-                                  imageinfo_get_full_name (ii_info),
-                                  dd_data->s_cfg_file) != ERR_OK) {
-
-            message_dialog_error (dd_data->gw_window, "Some error occured"); 
+        i_err = wallpaper_dialog_set (s_cmd,
+                                      imageinfo_get_full_name (ii_info),
+                                      dd_data->s_cfg_file);
+        if (i_err != ERR_OK) {
+            message_dialog_error (dd_data->gw_window, err_get_message (i_err));
         }
         imageinfo_free (ii_info);
     }
@@ -738,18 +678,16 @@ event_save_settings_pressed (GtkWidget  *widget,
                              DialogData *dd_data)
 {
     SettList *st_list;
-    int       i_res = 0;
+    int       i_err = 0;
 
     st_list = widgets_get_settings (dd_data);
 
-    i_res = settings_check_update_file (st_list, dd_data->s_cfg_file);
+    i_err = settings_check_update_file (st_list, dd_data->s_cfg_file);
 
     stlist_free (st_list);
 
-    /* Save setting to config file */
-    if (i_res != ERR_OK) {
-        message_dialog_error (dd_data->gw_window,
-                              "Error while saving settings");
+    if (i_err != ERR_OK) {
+        message_dialog_error (dd_data->gw_window, err_get_message (i_err));
         /* g_application_quit (G_APPLICATION (dd_data)); */
     }
 }
@@ -760,7 +698,7 @@ event_save_settings_pressed (GtkWidget  *widget,
 static void
 event_about_app_pressed (GtkWidget  *widget)
 {
-    about_app_dialog (APP_VER);
+    about_app_dialog (APP_VERSION);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -787,6 +725,65 @@ event_img_list_activated (GtkTreeView       *tree_view,
     }
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Interval spin changed
+ */
+static void
+event_interval_changed (GtkSpinButton *spin_button,
+                        DialogData    *dd_data)
+{
+    static int i_prev = 0; /* Previous interval value */
+    int        i_val  = 0; /* Actual interval value */
+    int        i_act  = 0; /* Active interval combo index */
+
+    i_val = gtk_spin_button_get_value_as_int (spin_button);
+
+    if (i_prev == 1 && i_val != 1) {
+
+        i_act = gtk_combo_box_get_active (
+                GTK_COMBO_BOX (dd_data->gw_inter_combo));
+
+        gtk_combo_box_text_remove_all (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo));
+
+        gtk_combo_box_text_append (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo),
+                NULL,
+                "minutes");
+
+        gtk_combo_box_text_append (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo),
+                NULL,
+                "hours");
+
+        gtk_combo_box_set_active (GTK_COMBO_BOX (dd_data->gw_inter_combo),
+                                                 i_act);
+    }
+    else if (i_prev != 1 && i_val == 1) {
+
+        i_act = gtk_combo_box_get_active (
+                GTK_COMBO_BOX (dd_data->gw_inter_combo));
+
+        gtk_combo_box_text_remove_all (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo));
+
+        gtk_combo_box_text_append (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo),
+                NULL,
+                "minute");
+
+        gtk_combo_box_text_append (
+                GTK_COMBO_BOX_TEXT (dd_data->gw_inter_combo),
+                NULL,
+                "hour");
+
+        gtk_combo_box_set_active (GTK_COMBO_BOX (dd_data->gw_inter_combo),
+                                                 i_act);
+    }
+
+    i_prev = i_val;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  On main window delete, check settings.
  */
@@ -798,8 +795,8 @@ event_on_delete (GtkWidget  *window,
     GtkWidget *dialog;
     SettList  *st_list;
     char      *s_buff = NULL;
-    int        i_res2 = 0;
     int        i_res  = 0;
+    int        i_err  = 0;
     int        i_w    = 0;
     int        i_h    = 0;
 
@@ -807,12 +804,12 @@ event_on_delete (GtkWidget  *window,
 
     st_list = widgets_get_settings (dd_data);
 
-    i_res = settings_check_update (st_list, dd_data->s_cfg_file, &s_buff);
+    s_buff = settings_check_update (st_list, dd_data->s_cfg_file, &i_err);
 
     stlist_free (st_list);
 
-    if (i_res != ERR_OK) {
-        message_dialog_error (dd_data->gw_window, "Some error occured"); 
+    if (i_err != ERR_OK) {
+        message_dialog_error (GTK_WINDOW (window), err_get_message (i_err));
     }
 
     if (s_buff != NULL) {
@@ -824,18 +821,19 @@ event_on_delete (GtkWidget  *window,
 
         gtk_window_set_title (GTK_WINDOW (dialog), "Settings changed");
 
-        i_res2 = gtk_dialog_run (GTK_DIALOG (dialog));
+        i_res = gtk_dialog_run (GTK_DIALOG (dialog));
 
         gtk_widget_destroy (dialog);
 
-        if (i_res2 == GTK_RESPONSE_YES) {
+        if (i_res == GTK_RESPONSE_YES) {
 
-            i_res = settings_update_file (s_buff, dd_data->s_cfg_file);
+            i_err = settings_update_file (s_buff, dd_data->s_cfg_file);
 
-            if (i_res != ERR_OK) {
-                message_dialog_error (dd_data->gw_window, "Some error occured"); 
+            if (i_err != ERR_OK) {
+                message_dialog_error (GTK_WINDOW (window),
+                                      err_get_message (i_err));
             }
-        } 
+        }
         free (s_buff);
     }
 
@@ -1057,11 +1055,14 @@ create_settings_widget (GtkWidget **gw_widget,
                                "hours");
     gtk_combo_box_set_active (GTK_COMBO_BOX (gw_time_combo), 0);
 
+    g_signal_connect (gw_spinbutton, "value-changed",
+                  G_CALLBACK (event_interval_changed), dd_data);
+
     /* Setting pointers in DialogData */
-    dd_data->gw_random = gw_button_random;
-    dd_data->gw_lastused = gw_button_selectlast;
-    dd_data->gw_command = gw_command_entry;
-    dd_data->gw_interval = gw_spinbutton;
+    dd_data->gw_random      = gw_button_random;
+    dd_data->gw_lastused    = gw_button_selectlast;
+    dd_data->gw_command     = gw_command_entry;
+    dd_data->gw_interval    = gw_spinbutton;
     dd_data->gw_inter_combo = gw_time_combo;
 
     /* Container for settings widgets */
@@ -1118,20 +1119,23 @@ activate (GtkApplication *app,
     const char *s_lastused = NULL;  /* Last used wallpaper path */
     int         i_err      = 0;     /* For error output */
 
-    dd_data->s_cfg_file = NULL;
+    memset (dd_data->s_cfg_file, 0, sizeof (dd_data->s_cfg_file));
+
+    i_err = set_config_file_path (dd_data->s_cfg_file);
 
-    dd_data->s_cfg_file = check_config_path_file (&i_err);
     if (i_err != ERR_OK) {
+        message_dialog_error (NULL, err_get_message (i_err));
         g_application_quit (G_APPLICATION (app));
         return;
     }
+
     /* Image preview widget */
     gw_img_prev = gtk_image_new ();
 
     /* Main window */
     gw_window = gtk_application_window_new (app);
     gtk_window_set_title (GTK_WINDOW (gw_window),
-                          APP_NAME " v" APP_VER);
+                          APP_NAME " v" APP_VERSION);
     g_signal_connect (gw_window, "delete-event",
                   G_CALLBACK (event_on_delete), dd_data);
     dd_data->gw_window = GTK_WINDOW (gw_window);
@@ -1202,16 +1206,21 @@ activate (GtkApplication *app,
 
     st_list = settings_read (dd_data->s_cfg_file, &i_err);
     if (i_err != ERR_OK) {
+        message_dialog_error (NULL, err_get_message (i_err));
         stlist_free (st_list);
         g_application_quit (G_APPLICATION (app));
         return;
     }
 
+    settlist_check_defaults (st_list);
+
     widgets_set_settings (dd_data, st_list);
 
     st_sett = stlist_get_setting_with_name (
             st_list, get_setting_name (SETTING_LAST_USED_STR));
-    s_lastused = setting_get_string (st_sett);
+
+    if (st_sett != NULL)
+        s_lastused = setting_get_string (st_sett);
 
     /* Check if there is last used wallpaper info, if it is select it on
      * list and make a preview image */
@@ -1233,7 +1242,7 @@ static void
 shutdown (GtkApplication *app,
           DialogData     *dd_data)
 {
-    free (dd_data->s_cfg_file);
+    //free (dd_data->s_cfg_file);
 }
 /*----------------------------------------------------------------------------*/
 /**
