@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date December 9, 2019
+ * @date December 22, 2019
  *
- * @version 1.3.4
+ * @version 1.3.5
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -32,9 +32,9 @@
 #include "setts.h"
 #include "wallsett.h"
 #include "wpset.h"
-#include "miscfun.h"
-#include "flist.h"
+#include "rwdt.h"
 #include "randomm.h"
+#include "settlist.h"
 #include "errs.h"
 /*----------------------------------------------------------------------------*/
 /**
@@ -51,50 +51,105 @@ main (int    argc,
 {
     SettList *st_list;
     WallSett  ws_sett;
-    uint32_t  ui_cnt = 0;
-    int       i_err  = 0;
+    uint32_t  ui_cnt  = 0;
+    uint32_t  ui_len  = 0;
+    uint32_t  ui_nlen = 0;
+    int       i_err   = 0;
 
     if (wallset_init (&ws_sett) != ERR_OK) {
-        wallset_free (&ws_sett);
         exit (EXIT_FAILURE);
     }
 
     st_list = settings_read (ws_sett.s_cfgfile, &i_err);
+
     if (i_err != ERR_OK) {
         stlist_free (st_list);
         wallset_free (&ws_sett);
         exit (EXIT_FAILURE);
     }
 
-    settlist_to_wallset (st_list, &ws_sett);
-    stlist_free (st_list);
+    if (stlist_get_length (st_list) == 0) {
+        fputs ("Empty config file\n", stderr);
+        stlist_free (st_list);
+        exit (EXIT_FAILURE);
+    }
 
-    if (flist_get_len (&ws_sett.fl_files) == 0) {
-        fputs ("Empty file list\n", stderr);
+    settlist_check_defaults (st_list);
+
+    settlist_to_wallset (st_list, &ws_sett);
+
+    ui_len = stlist_get_length (ws_sett.sl_walls);
+
+    if (ui_len == 0) {
+        fputs ("Empty wallpaper list\n", stderr);
+        stlist_free (st_list);
         wallset_free (&ws_sett);
         exit (EXIT_FAILURE);
     }
 
     /* Set the maximun random range to the length of the file list */
-    randomm_set_range (&ws_sett.rm_mem, flist_get_len (&ws_sett.fl_files));
+    randomm_set_range (&ws_sett.rm_mem, ui_len);
 
     if (wallpaper_startup_set (&ws_sett) != ERR_OK) {
+        stlist_free (st_list);
         wallset_free (&ws_sett);
         exit (EXIT_FAILURE);
     }
 
+    stlist_free (st_list);
+    wallset_free (&ws_sett);
+
     while (1) {
+
         sleep (60);
         ui_cnt++;
+
         if (ui_cnt >= ws_sett.i_chinterval) {
+
+            st_list = settings_read (ws_sett.s_cfgfile, &i_err);
+
+            if (i_err != ERR_OK) {
+                stlist_free (st_list);
+                wallset_free (&ws_sett);
+                exit (EXIT_FAILURE);
+            }
+
+            if (stlist_get_length (st_list) == 0) {
+                fputs ("Empty config file\n", stderr);
+                stlist_free (st_list);
+                exit (EXIT_FAILURE);
+            }
+
+            settlist_check_defaults (st_list);
+
+            settlist_to_wallset (st_list, &ws_sett);
+
+            ui_nlen = stlist_get_length (ws_sett.sl_walls);
+
+            if (ui_nlen == 0) {
+                fputs ("Empty wallpaper list\n", stderr);
+                stlist_free (st_list);
+                wallset_free (&ws_sett);
+                exit (EXIT_FAILURE);
+            }
+
+            if (ui_nlen != ui_len) {
+                randomm_init (&ws_sett.rm_mem);
+                randomm_set_range (&ws_sett.rm_mem, ui_nlen);
+                ui_len = ui_nlen;
+            }
+
             if (wallpaper_change (&ws_sett) != ERR_OK) {
+                stlist_free (st_list);
                 wallset_free (&ws_sett);
                 exit(EXIT_FAILURE);
             }
+
+            stlist_free (st_list);
+            wallset_free (&ws_sett);
             ui_cnt = 0;
         }
     }
-    wallset_free (&ws_sett);
 
     return 0;
 }
