@@ -25,75 +25,86 @@
 #include <stdlib.h>
 #include <stdint.h>
 #include "setts.h"
-#include "flist.h"
 #include "randomm.h"
-#include "miscfun.h"
+#include "strfun.h"
 #include "wpset.h"
+#include "settlist.h"
+#include "errs.h"
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  static int wallpaper_set_file (const char *s_cmd,
- *                                     const char *s_wall)
+ * @fn  static void wallpaper_set_file (const char *s_cmd,
+ *                                      const char *s_wall)
  * @brief         Set particular file as a wallpaper. 
  * @param[in]     s_cmd   Wallpaper set command
  * @param[in]     s_wall  Wallpaper file
  * @return        Wallpaper set status
  *
- * @fn  static int wallpaper_set_random (WallSett *ws_sett)
+ * @fn  static void wallpaper_set_random (WallSett *ws_sett)
  * @brief         Set random image from list as a wallpaper.
  * @param[in,out] ws_sett  Program settings
  * @return        Wallpaper set status
  *
- * @fn  static int wallpaper_set_next_in_list (WallSett *ws_sett)
+ * @fn  static void wallpaper_set_next_in_list (WallSett *ws_sett)
  * @brief         Set next wallpaper from list.
  * @param[in,out] ws_sett  Program settings
  * @return        Wallpaper change status
  */
 /*----------------------------------------------------------------------------*/
-static int wallpaper_set_file         (const char *s_cmd,
-                                       const char *s_wall);
+static void wallpaper_set_file         (const char *s_cmd,
+                                        const char *s_wall);
 
-static int wallpaper_set_random       (WallSett   *ws_sett);
+static void wallpaper_set_random       (WallSett   *ws_sett);
 
-static int wallpaper_set_next_in_list (WallSett   *ws_sett);
+static void wallpaper_set_next_in_list (WallSett   *ws_sett);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set particular file as a wallpaper. 
  */
-static int
+static void
 wallpaper_set_file (const char *s_cmd,
                     const char *s_wall)
 {
     char *s_cmdn = NULL; /* Wallpaper set command */
 
-    s_cmdn = set_up_wallpaper_command (s_cmd, s_wall, "[F]");
+    s_cmdn = str_set_up_wallpaper_command (s_cmd, s_wall, "[F]");
+
+    if (s_cmdn == NULL)
+        return;
+
+    #ifdef DEBUG
+    printf ("Setting wallpaper command %s\n", s_cmdn);
+    #endif
 
     system (s_cmdn);
 
     free (s_cmdn);
 
-    return 0;
+    return;
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set random image from list as a wallpaper.
  */
-static int
+static void
 wallpaper_set_random (WallSett *ws_sett)
 {
-    const char *s_fn  = NULL; /* Wallpaper file name */
-    uint32_t    i_pos = 0;    /* Random wallpaper position */
-    uint32_t    i_cnt = 0;    /* Length of wallpaper list */
+    const char *s_fn   = NULL; /* Wallpaper file name */
+    uint32_t    i_pos  = 0;    /* Random wallpaper position */
+    uint32_t    ui_len = 0;    /* Length of wallpaper list */
+
+    const SettList *sl_walls = wallset_get_wallpaper_list (ws_sett);
 
     /* Get wallpaper list length */
-    i_cnt = flist_get_len (&ws_sett->fl_files);
-    if (i_cnt == 0)
-        return 0;
+    ui_len = stlist_get_length (sl_walls);
+    if (ui_len == 0)
+        return;
 
     /* Get random number */
     i_pos = randomm_get_number (&ws_sett->rm_mem);
 
     /* Get the file name at the random position */
-    s_fn = flist_get_data (&ws_sett->fl_files, i_pos);
+    s_fn = setting_get_string (
+            stlist_get_setting_at_pos (sl_walls, i_pos));
 
     if (s_fn != NULL) {
 
@@ -104,60 +115,50 @@ wallpaper_set_random (WallSett *ws_sett)
         wallpaper_set_file (wallset_get_command (ws_sett),
                             wallset_get_last_used_fn (ws_sett));
     }
-    return 0;
+    return;
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set next wallpaper from list.
  */
-static int
+static void
 wallpaper_set_next_in_list (WallSett *ws_sett)
 {
     const char *s_next = NULL; /* Next wallpaper file name */
     int         i_pos  = 0;    /* Next wallpaper position in list */
+    uint32_t    ui_len = 0;    /* Wallpaper list length */
 
-    /* check empty list */
-    if (flist_get_len (&ws_sett->fl_files) == 0) {
-        return 0;
+    const SettList *sl_walls = wallset_get_wallpaper_list (ws_sett);
+
+    /* check for empty list */
+    ui_len = stlist_get_length (sl_walls);
+
+    if (ui_len == 0)
+        return;
+
+    if (wallset_get_last_used_fn (ws_sett) != NULL) {
+        /* Get from the file list position of the last used wallpaper
+         * and increment it */
+        i_pos = stlist_get_setting_val_str_pos (sl_walls,
+                wallset_get_last_used_fn (ws_sett)) + 1;
     }
-    
-    /* If last used wallpaper is null get first one on list */
-    if (wallset_get_last_used_fn (ws_sett) == NULL) {
-
+    /* If last used wallpaper was the last one get first one */
+    if ((uint32_t) i_pos >= ui_len)
         i_pos = 0;
-        s_next = flist_get_data (&ws_sett->fl_files, i_pos);
 
+    /* Get next wallpaper from list */
+    s_next = setting_get_string (
+            stlist_get_setting_at_pos (sl_walls, (uint32_t) i_pos));
+
+    if (s_next != NULL) {
         /* Save wallpaper as last used in settings */
         wallset_set_last_used_fn (ws_sett, s_next);
 
         /* Set wallpaper */
         wallpaper_set_file (wallset_get_command (ws_sett),
                             wallset_get_last_used_fn (ws_sett));
-        return 0;
     }
-    /* Get from the file list position of the last used wallpaper
-     * and increment it */
-    i_pos = flist_get_pos (&ws_sett->fl_files,
-                           wallset_get_last_used_fn (ws_sett)) + 1;
-    if (i_pos >= 0) {
-
-        /* Get next wallpaper from list */
-        s_next = flist_get_data (&ws_sett->fl_files, i_pos);
-
-        /* If last used wallpaper was the last one get first one */
-        if (s_next == NULL) {
-            s_next = flist_get_data (&ws_sett->fl_files, 0);
-        }
-        else  {
-            /* Save wallpaper as last used in settings */
-            wallset_set_last_used_fn (ws_sett, s_next);
-
-            /* Set wallpaper */
-            wallpaper_set_file (wallset_get_command (ws_sett),
-                                wallset_get_last_used_fn (ws_sett));
-        }
-    }
-    return 0;
+    return;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -186,8 +187,15 @@ wallpaper_startup_set (WallSett *ws_sett)
 
     if (wallset_get_last_used_setting (ws_sett)) {
 
-        wallpaper_set_file (wallset_get_command (ws_sett),
-                            wallset_get_last_used_fn (ws_sett));
+        if (wallset_get_last_used_fn (ws_sett) == NULL) {
+
+            i_res = wallpaper_change (ws_sett);
+        }
+        else {
+
+            wallpaper_set_file (wallset_get_command (ws_sett),
+                                wallset_get_last_used_fn (ws_sett));
+        }
     }
     else {
         i_res = wallpaper_change (ws_sett);
@@ -205,9 +213,7 @@ wallpaper_dialog_set (const char *s_cmd,
 {
     int i_res = 0;
 
-    i_res = wallpaper_set_file (s_cmd, s_file);
-    if (i_res)
-        return i_res;
+    wallpaper_set_file (s_cmd, s_file);
 
     i_res = settings_update_last_used (s_file, s_cfg_file);
 
